@@ -332,7 +332,7 @@ void Principal::click_open()
     }
     else
     {
-        url=fileName;
+        url.setPath(fileName);
     }
 
     if( url.isLocalFile() )
