@@ -34,6 +34,7 @@
 #include "portablekde.h"
 #include "execdlg.h"
 #include "dirmanager.h"
+#include <arts/debug.h>
 
 #ifndef KDE_USE_FINAL
 static void min_size(QWidget *w) {
@@ -190,7 +191,7 @@ void ExecDlg::saveSession()
 	QString filename = KFileDialog::getSaveFileName(0,"*.arts-session",this);
 	if(!filename.isEmpty())
 	{
-		printf("save... %s\n",filename.local8Bit().data());
+		arts_debug("save... %s",filename.local8Bit().data());
 		structure->saveSession(QFile::encodeName(filename));
 	}
 }
