@@ -1,7 +1,7 @@
-	/*
+/*
 
-	Copyright (C) 1998 Stefan Westerfeld
-                       stefan@space.twc.de
+	Copyright (C) 1998 - 2000 Stefan Westerfeld
+                              stefan@space.twc.de
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,6 +40,8 @@
 #include <kfiledialog.h>
 #include <ksimpleconfig.h>
 #include <kmessagebox.h>
+#include <kaboutdata.h>
+#include <kstddirs.h>
 #include <qlistbox.h>
 #include <qscrollview.h>
 #include <qtablevw.h>
@@ -51,6 +53,7 @@
 #include <qpixmap.h>
 #include <string.h>
 #include <unistd.h>
+#include <arts/debug.h>
 #include "module.h"
 #include "autorouter.h"
 #include "portpropdlg.h"
@@ -58,6 +61,8 @@
 #include "execdlg.h"
 #include "namedlg.h"
 
+using namespace std;
+
 /*************************************/
 class ArtsBuilderApp :public KApplication
 {
@@ -65,6 +70,7 @@ protected:
 	ModuleView *moduleview;
 public:
 	ArtsBuilderApp();
+	ArtsBuilderApp(QString filename);
 	void start();
 	void end();
 };
@@ -145,7 +151,7 @@ void ModuleWidget::mousePressEvent( QMouseEvent *e )
 		cellx = e->x() - cellx;
 		celly = e->y() - celly;
 
-		//printf("clicked at %d,%d\n",cellx,celly);
+		//arts_debug("clicked at %d,%d",cellx,celly);
 
 		StructureComponent *c = structure->componentAt(x,y,false);
 		ModulePort *port = NULL;
@@ -417,6 +423,52 @@ void ModuleWidget::reRoute()
 
 // add connections to the router
 
+	/*
+	 * assign colors after the following algorithm:
+	 *
+	 * - initialize assuming that each port has its own color
+	 * - if two ports are connected, they must have the same color, that
+	 *   is, all references to the two colors must be made the same
+	 *
+	 * these colors are not used for drawing, but for making lines of
+	 * different groups of ports not collide in the autorouter (ownership)
+	 */
+	map<ModulePort *, long> color;
+	vector<long> owner(portlist.size());
+
+	long maxcolor = 0;
+	for(pi = portlist.begin();pi != portlist.end();pi++)
+		color[*pi] = maxcolor++;
+
+	for(pi = portlist.begin();pi != portlist.end();pi++)
+	{
+		ModulePort *src = *pi;
+		unsigned long c;
+		if(src->direction == ModulePort::out && src->PortDesc.isConnected())
+		{
+			vector<Arts::PortDesc> *conn = src->PortDesc.connections();
+
+			for(c=0;c<conn->size();c++)
+			{
+				ModulePort *dest = portmap[(*conn)[c].ID()];
+				long color_src = color[src];
+				long color_dest = color[dest];
+
+				if(color_src != color_dest)
+				{
+					list<ModulePort *>::iterator pi2;
+
+					for(pi2 = portlist.begin();pi2 != portlist.end();pi2++)
+					{
+						ModulePort *p = *pi2;
+
+						if(color[p] == color_dest) color[p] = color_src;
+					}
+				}
+			}
+		}
+	}
+
 	for(pi = portlist.begin();pi != portlist.end();pi++)
 	{
 		ModulePort *p = *pi;
@@ -424,7 +476,7 @@ void ModuleWidget::reRoute()
 		if(p->direction == ModulePort::out && p->PortDesc.isConnected())
 		{
 			ModulePort *src = p, *dest;
-			long route_owner = 0;
+			long& route_owner = owner[color[src]];
 			unsigned long c;
 
 			vector<Arts::PortDesc> *conn = p->PortDesc.connections();
@@ -435,7 +487,7 @@ void ModuleWidget::reRoute()
 				if(dest)		// otherwise something bad has happend?
 				{
 /*
-						printf("autoroute add connection port %s.%s to %s.%s\n",
+						arts_debug("autoroute add connection port %s.%s to %s.%s",
 							src->owner->type.local8Bit().data(),src->description.local8Bit().data(),
 							dest->owner->type.local8Bit().data(),dest->description.local8Bit().data());
 */
@@ -622,12 +674,12 @@ void ModuleWidget::autoRedrawRouter()
 ModuleWidget::ModuleWidget(Structure *structure, QWidget *parent, const char *name, WFlags f)
 		:QTableView(parent,name,f)
 {
-	cout << "PORT: mw; getmodulelist" << endl;
+	arts_debug("PORT: mw; getmodulelist");
 	this->ModuleList = structure->getModuleList();
 	this->structure = structure;
 	activeTool = 0;
 	mouseButtonDown = false;
-	cout << "PORT: mw; cols&rows" << endl;
+	arts_debug("PORT: mw; cols&rows");
 
 	cols = 24;
 	rows = 32;
@@ -637,18 +689,18 @@ ModuleWidget::ModuleWidget(Structure *structure, QWidget *parent, const char *na
 	setTableFlags(Tbl_autoScrollBars);
 	setZoom(100);
 
-	cout << "PORT: mw; bgmode" << endl;
+	arts_debug("PORT: mw; bgmode");
 	setBackgroundMode(NoBackground);
 
 	selectedports = 0;
-	cout << "PORT: mw; new ar" << cols << "," << rows << endl;
+	arts_debug("PORT: mw; new ar %d,%d", cols, rows);
 	autorouter = new AutoRouter(cols*2,rows*2);
-	cout << "PORT: mw; new ar ok - qtimer" << endl;
+	arts_debug("PORT: mw; new ar ok - qtimer");
 
     QTimer *timer = new QTimer( this );
 	connect( timer, SIGNAL(timeout()),
 		this, SLOT(autoRedrawRouter()) );
-	cout << "PORT: mw; tstart" << endl;
+	arts_debug("PORT: mw; tstart");
 	timer->start( 100, FALSE );                 // 100 ms reoccuring check
 };
 
@@ -661,18 +713,18 @@ ModuleView::ModuleView(const char *name) : KMainWindow(0, name)
 {
 	KStdAccel keys;
  
-	printf("PORT: structure\n");
+	arts_debug("PORT: structure");
 	structure = new Structure();
-	printf("PORT: structure ok\n");
+	arts_debug("PORT: structure ok");
 	//ModuleList = structure->getModuleList();
 
-	printf("PORT: modulewidget\n");
+	arts_debug("PORT: modulewidget");
 	modulewidget = new ModuleWidget(structure, this, "mwidget");
-	printf("PORT: modulewidget ok\n");
+	arts_debug("PORT: modulewidget ok");
 
-	printf("PORT: setcanvas \n");
+	arts_debug("PORT: setcanvas");
 	structure->setCanvas(modulewidget);
-	printf("PORT: setcanvas ok\n");
+	arts_debug("PORT: setcanvas ok");
 
 	m_file = new QPopupMenu;
 	m_file_new = new QPopupMenu;
@@ -688,12 +740,15 @@ ModuleView::ModuleView(const char *name) : KMainWindow(0, name)
 	m_modules_other = new QPopupMenu;
 	*/
 
-	printf("PORT: first menu stuff \n");
+	arts_debug("PORT: first menu stuff");
 	m_file->insertItem(i18n("Open Session..."), this , SLOT(openSession()));
     m_file->insertSeparator();
 	m_file->insertItem(i18n("&New"), m_file_new);
 	m_file->insertItem(i18n("&Open..."), this , SLOT(open()), keys.open());
-	m_file->insertItem(i18n("&Save..."), this , SLOT(save()), keys.save());
+	m_file->insertItem(i18n("Open E&xample..."), this , SLOT(openExample()));
+	m_file->insertItem(i18n("Save &As..."), this , SLOT(saveAs()));
+	m_file->insertItem(i18n("&Save..."), this , SLOT(save()), keys.save(), id_save);
+	m_file->setItemEnabled(id_save, false);
 	m_file->insertItem(i18n("&Retrieve from server..."), this, SLOT(retrieve()));
     m_file->insertSeparator();
 	m_file->insertItem(i18n("&Execute Structure..."), this, SLOT(execute()));
@@ -728,7 +783,7 @@ ModuleView::ModuleView(const char *name) : KMainWindow(0, name)
 //---- publish my widgets on the server ----
 
 	GUIServer=new GUIServer_impl(ModuleBroker,Synthesizer);
-    printf("GUIServer:\n%s\n",ArtsOrb->object_to_string(GUIServer));
+    arts_debug("GUIServer:\n%s",ArtsOrb->object_to_string(GUIServer));
 	GUIServer->incRef();
 
 //---- trigger autoloading of all structures that are present in my dirs ----
@@ -746,7 +801,7 @@ ModuleView::ModuleView(const char *name) : KMainWindow(0, name)
 	/*
 	string common = (const char *)PortableKDE::globalDir("data");
 	common += "/artsbuilder";
-	printf("%s\n",common.c_str());
+	arts_debug("%s",common.c_str());
 	if(chdir(common.c_str()) == 0)
 		ModuleBroker->addPublishingPath(common.c_str());
 	*/
@@ -766,17 +821,9 @@ ModuleView::ModuleView(const char *name) : KMainWindow(0, name)
 
 	mbroker_updateCount = 0;
 	execDlg = 0;
-
-// WABA: Please consider using KAboutData.
-// WABA: See also KCmdLineArgs::init(...) in main(...)
-    QString about = i18n("Arts Builder 0.4.0");
-    about += i18n("\n\n(C) 1998-1999 Stefan Westerfeld <stefan@twc.de>\n\n"
-	       "Arts synthesizer designer.\n\n"
-		   "aRts Homepage: http://www.arts-project.org/");
-
-    QPopupMenu *m_help = helpMenu(about);
+	KPopupMenu *m_help =  helpMenu(0, FALSE);
 		       
-	printf("PORT: kmenubar \n");
+	arts_debug("PORT: kmenubar");
 	menubar = new KMenuBar (this, "menubar");
 	menubar->insertItem (i18n("&File"), m_file);
 	menubar->insertItem (i18n("&Edit"), m_edit);
@@ -786,10 +833,10 @@ ModuleView::ModuleView(const char *name) : KMainWindow(0, name)
 	menubar->insertSeparator();
 	menubar->insertItem( i18n("&Help"), m_help);
 
-	printf("PORT: setCentralWidget \n");
+	arts_debug("PORT: setCentralWidget");
 	setCentralWidget(modulewidget);
 
-	printf("PORT: menumaker\n");
+	arts_debug("PORT: menumaker");
 	menumaker = new MenuMaker(m_modules);
 	//menumaker->addCategory("&Gui","Gui_");
 	menumaker->addCategory(i18n("&Synthesis"),"Arts::Synth_");
@@ -803,8 +850,12 @@ ModuleView::ModuleView(const char *name) : KMainWindow(0, name)
 	menumaker->addCategory(i18n("&Synthesis/&Delays"),"Arts::Synth_CDELAY$");
 	menumaker->addCategory(i18n("&Synthesis/&Envelopes"),"Arts::Synth_PSCALE$");
 	menumaker->addCategory(i18n("&Synthesis/&Envelopes"),"Arts::Synth_ENVELOPE_");
+	menumaker->addCategory(i18n("&Synthesis/Effe&cts"),"Arts::Synth_FREEVERB$");
 	menumaker->addCategory(i18n("&Synthesis/Effe&cts"),"Arts::Synth_FX_");
+	menumaker->addCategory(i18n("&Synthesis/Effe&cts"),"Arts::Synth_PITCH_SHIFT$");
+	menumaker->addCategory(i18n("&Synthesis/Effe&cts"),"Arts::Synth_TREMOLO$");
 	menumaker->addCategory(i18n("&Synthesis/&Filters"),"Arts::Synth_ATAN_SATURATE$");
+	menumaker->addCategory(i18n("&Synthesis/&Filters"),"Arts::Synth_BRICKWALL_LIMITER$");
 	menumaker->addCategory(i18n("&Synthesis/&Filters"),"Arts::Synth_MOOG_VCF");
 	menumaker->addCategory(i18n("&Synthesis/&Filters"),"Arts::Synth_SHELVE_CUTOFF$");
 	menumaker->addCategory(i18n("&Synthesis/&Filters"),"Arts::Synth_RC$");
@@ -815,12 +866,14 @@ ModuleView::ModuleView(const char *name) : KMainWindow(0, name)
 	menumaker->addCategory(i18n("&Synthesis/&Midi + Sequencing"),"Arts::Synth_STRUCT_KILL$");
 	menumaker->addCategory(i18n("&Synthesis/Sam&ples "),"Arts::Synth_PLAY_");
 	menumaker->addCategory(i18n("&Synthesis/&Sound IO"),"Arts::Synth_AMAN_");
+	menumaker->addCategory(i18n("&Synthesis/&Sound IO"),"Arts::Synth_CAPTURE_WAV$");
 	menumaker->addCategory(i18n("&Synthesis/&Sound IO"),"Arts::Synth_PLAY$");
 	menumaker->addCategory(i18n("&Synthesis/&Sound IO"),"Arts::Synth_RECORD$");
 	menumaker->addCategory(i18n("&Synthesis/&Sound IO"),"Arts::Synth_FULL_DUPLEX_");
 	menumaker->addCategory(i18n("&Synthesis/&Sound IO"),"Arts::Synth_FILEPLAY");
 	menumaker->addCategory(i18n("&Synthesis/&Tests"),"Arts::Synth_NIL$");
 	menumaker->addCategory(i18n("&Synthesis/&Tests"),"Arts::Synth_DEBUG$");
+	menumaker->addCategory(i18n("&Synthesis/&Tests"),"Arts::Synth_DATA$");
 	menumaker->addCategory(i18n("&Synthesis/&Tests"),"Arts::Synth_MIDI_DEBUG$");
 	menumaker->addCategory(i18n("&Synthesis/&Oscillation & Modulation"),"Arts::Synth_FREQUENCY$");
 	menumaker->addCategory(i18n("&Synthesis/&Oscillation & Modulation"),"Arts::Synth_FM_SOURCE$");
@@ -833,7 +886,7 @@ ModuleView::ModuleView(const char *name) : KMainWindow(0, name)
 	menumaker->addCategory(i18n("&Mixer-Elements"),"mixer_element_");
 	menumaker->addCategory(i18n("&Templates"),"template_");
 	menumaker->addCategory(i18n("&Other"),"*");
-	printf("PORT: menumaker ok\n");
+	arts_debug("PORT: menumaker ok");
 
 /*
 	m_modules->insertItem(i18n("&Gui"), m_modules_gui);
@@ -858,9 +911,12 @@ ModuleView::ModuleView(const char *name) : KMainWindow(0, name)
 	connect(kapp,SIGNAL(lastWindowClosed()), this , SLOT(quit()));
 
 	// update the modules menu once for the start
-	printf("PORT: activatemenu\n");
+	arts_debug("PORT: activatemenu");
 	activateMenu(modules_menu_item);
-	printf("PORT: activatemenu ok\n");
+	arts_debug("PORT: activatemenu ok");
+
+	m_filename = (QString) 0;
+	modified = false;
 }
 
 void ModuleView::activateMenu(int)
@@ -939,9 +995,9 @@ void ModuleView::activateMenu(int)
 void ModuleView::quit()
 {
 	if(execDlg) return;
-	printf(">> ModuleView::quit() called\n");
+	arts_debug(">> ModuleView::quit() called");
 	kapp->quit();
-	printf("<< leaving ModuleView::quit()\n");
+	arts_debug("<< leaving ModuleView::quit()");
 }
 
 ModuleView::~ModuleView()
@@ -952,6 +1008,7 @@ ModuleView::~ModuleView()
 void ModuleView::clear()
 {
 	structure->clear();
+	setModified(false);
 }
 
 void ModuleView::publish()
@@ -965,12 +1022,12 @@ void ModuleView::publish()
 
 QString ModuleView::getOpenFilename(const char *pattern)
 {
-	printf(">>>>> getOpenFilename\n");
+	arts_debug(">>>>> getOpenFilename");
 	QString filename = KFileDialog::getOpenFileName(0,pattern,this);
-	printf(">>>>> opendlg closed\n");
+	arts_debug(">>>>> opendlg closed");
 	if(!filename.isEmpty())
 	{
-		printf("open... %s\n",filename.local8Bit().data());
+		arts_debug("open... %s",filename.local8Bit().data());
 
 		// check that the file is ok:
 
@@ -987,8 +1044,22 @@ QString ModuleView::getOpenFilename(const char *pattern)
 
 void ModuleView::open()
 {
+	if (!promptToSave())
+		return;
+
 	chdir(DirManager::structureDir());
-	QString filename = getOpenFilename("*.arts");
+	QString	filename = getOpenFilename("*.arts");
+	open(filename);
+	m_filename = filename;
+	m_file->setItemEnabled(id_save, true);
+	setModified(false);
+	setCaption(m_filename);
+}
+
+void ModuleView::open(QString filename)
+{
+	if (!promptToSave())
+		return;
 
 	if(!filename.isEmpty())
 	{
@@ -996,17 +1067,24 @@ void ModuleView::open()
 		modulewidget->reInit();
 		if(!structure->valid())
 		{
-   			KMessageBox::sorry( 0, 
+			KMessageBox::sorry( 0, 
 			i18n("The structure couldn't be loaded correctly. Maybe some of\n"
 				 "the modules used in the file aren't available in this\n"
 				 "version of aRts."),
 				i18n("Arts Warning"));
 		}
+		m_filename = filename;
+		m_file->setItemEnabled(id_save, true);
+		setModified(false);
+		setCaption(m_filename);
 	}
 }
 
 void ModuleView::openSession()
 {
+	if (!promptToSave())
+		return;
+
 	chdir(DirManager::sessionDir());
 
 	QString filename = getOpenFilename("*.arts-session");
@@ -1030,10 +1108,33 @@ void ModuleView::openSession()
 		connect(execDlg,SIGNAL( ready() ), this, SLOT( endexecute() ));
 
 		hide();
+		setModified(false);
 	}
 }
 
-void ModuleView::save()
+void ModuleView::openExample()
+{
+	if (!promptToSave())
+		return;
+
+	QString dir = locate("data", "artsbuilder/examples/");
+	if (!dir)
+		KMessageBox::sorry(
+			0, 
+			i18n("Unable to find the examples directory.\nUsing the current directory instead."),
+			i18n("Arts Warning"));
+	else
+		chdir(dir); 
+
+	QString	filename = getOpenFilename("*.arts");
+	open(filename);
+	m_filename = filename;
+	m_file->setItemEnabled(id_save, true);
+	setModified(false);
+	setCaption(m_filename);
+}
+
+void ModuleView::saveAs()
 {
 	checkName();
 	chdir(DirManager::structureDir());
@@ -1043,29 +1144,78 @@ void ModuleView::save()
 
 	dlg->setSelection(defaultname.c_str());
 	dlg->setCaption(i18n("Open"));
-			  
-    if (dlg->exec() == QDialog::Accepted)
-    filename = dlg->selectedFile();
-					   
-    delete dlg;                                                                 
+
+	if (dlg->exec() == QDialog::Accepted)
+		filename = dlg->selectedFile();
+
+	delete dlg;
 	// QString filename = KFileDialog::getSaveFileName(0,"*.arts",this);
 	// filename.detach();
 
 	if(!filename.isEmpty())
 	{
-		printf("save... %s\n",filename.local8Bit().data());
+		arts_debug("save as... %s",filename.local8Bit().data());
 
 		// clear the file first:
 
 		FILE *outfile = fopen(filename,"w");
 
-		if(!outfile) return;
+		if (!outfile) {
+			KMessageBox::sorry(
+				0, 
+				i18n("The file could not be opened for writing."),
+				i18n("Arts Warning"));
+			return;
+		}
+
 		fclose(outfile);
 
-		structure->save(filename);
+		bool status = structure->save(filename);
+		if (!status) {
+			KMessageBox::sorry(
+				0, 
+				i18n("Unable to save to file."),
+				i18n("Arts Warning"));
+			return;
+		}
+
+		setModified(false);
+		m_filename = filename;
+		m_file->setItemEnabled(id_save, true);
+		setCaption(m_filename);
 	}
 }
 
+void ModuleView::save()
+{
+	arts_debug("save... %s", m_filename.local8Bit().data());
+
+	// clear the file first:
+
+	FILE *outfile = fopen(m_filename,"w");
+
+	if (!outfile) {
+		KMessageBox::sorry(
+			0, 
+			i18n("The file could not be opened for writing."),
+			i18n("Arts Warning"));
+		return;
+	}
+
+	fclose(outfile);
+
+	bool status = structure->save(m_filename);
+	if (!status) {
+		KMessageBox::sorry(
+			0, 
+			i18n("Unable to save to file."),
+			i18n("Arts Warning"));
+		return;
+	}
+
+	setModified(false);
+}
+
 void ModuleView::checkName()
 {
 	if(strncmp(structure->name().c_str(),"template_",strlen("template_")) == 0)
@@ -1079,14 +1229,18 @@ void ModuleView::rename()
 
 	if(nd->exec())
 	{
-		printf("rename OK...\n");
+		arts_debug("rename OK...");
 		structure->rename(nd->name());
 	}
 	delete nd;
+	setModified(true);
 }
 
 void ModuleView::retrieve()
 {
+	if (!promptToSave())
+		return;
+
 	RetrieveDlg *rd = new RetrieveDlg(0);
 	assert(rd);
 
@@ -1100,6 +1254,7 @@ void ModuleView::retrieve()
 		}
 	}
 	delete rd;
+	setModified(true);
 }
 
 void ModuleView::execute()
@@ -1143,49 +1298,55 @@ void ModuleView::endexecute()
 
 void ModuleView::fileNew(int what)
 {
+	if (!promptToSave())
+		return;
+
 	const char *name = menumaker->findID(what);
 	assert(name);
 	structure->retrieve(name);
 	modulewidget->reInit();
+	setModified(false);
 }
 
 void ModuleView::addPort(int port)
 {
 	Arts::PortType pt;
 
-	printf("selected (port=%d)\n", port);
+	arts_debug("selected (port=%d)", port);
 	switch(port)
 	{
 		case 1:		// data that goes into the structure
 			pt.direction = Arts::output;
-			pt.dataType = Arts::audio_data;
+			pt.dataType = "float";
 			pt.connType = Arts::conn_stream;
 			break;
 		case 2:		// data that goes out of the structure
 			pt.direction = Arts::input;
-			pt.dataType = Arts::audio_data;
+			pt.dataType = "float";
 			pt.connType = Arts::conn_stream;
 			break;
 		case 3:		// data that goes into the structure
 			pt.direction = Arts::output;
-			pt.dataType = Arts::string_data;
+			pt.dataType = "string";
 			pt.connType = Arts::conn_property;
 			break;
 		case 4:		// data that goes into the structure
 			pt.direction = Arts::output;
-			pt.dataType = Arts::audio_data;
+			pt.dataType = "float";
 			pt.connType = Arts::conn_property;
 			break;
 		default:	// forget it, no add intended
 			return;
 	}
 	modulewidget->addPort(pt);
+	setModified(true);
 }
 
 void ModuleView::changePortPositions()
 {
 	PortPosDlg *ppd = new PortPosDlg(this,structure);
 	ppd->exec();
+	setModified(true);
 	// XXX: delete ppd?
 }
 
@@ -1194,7 +1355,7 @@ void ModuleView::addModule(int module)
 	const char *name = menumaker->findID(module);
 	assert(name);
 
-	printf("selected (%s) (module=%d)\n", name,module);
+	arts_debug("selected (%s) (module=%d)", name, module);
 	Arts::ModuleInfo minfo = makeModuleInfo(name);
 
 	if(minfo.name != "")
@@ -1203,7 +1364,7 @@ void ModuleView::addModule(int module)
 	const char *name = menumaker->findID(module);
 	assert(name);
 
-	printf("selected (%s) (module=%d)\n", name,module);
+	arts_debug("selected (%s) (module=%d)", name, module);
 
 	ArtsCorba::ModuleBroker_var ModuleBroker = Synthesizer->moduleBroker();
 	ArtsCorba::ModuleInfo_var minfo = ModuleBroker->lookupModule(name);
@@ -1219,24 +1380,82 @@ void ModuleView::addModule(int module)
 */
 	}
 #endif
+	setModified(true);
 }
 
-ArtsBuilderApp::ArtsBuilderApp() 
+bool ModuleView::isModified()
+{
+	return modified;
+}
+
+void ModuleView::setModified(bool m)
+{
+	modified = m;
+}
+
+bool ModuleView::queryClose()
+{
+	return promptToSave();
+}
+
+bool ModuleView::promptToSave()
+{
+	bool result;
+	int query;
+
+	if (!isModified())
+		return true;
+
+	query = KMessageBox::warningYesNoCancel(
+		0,
+		i18n("The current document has been modified.\nWould you like to save it?"));
+
+	switch (query)
+	{
+	  case KMessageBox::Yes:
+		  saveAs();
+		  result = true;
+		  setModified(false);
+		  break;
+	  case KMessageBox::No:
+		  result = true;
+		  setModified(false);
+		  break;
+	  case KMessageBox::Cancel:
+		  result = false;
+		  break;
+	}
+	return result;
+}
+
+ArtsBuilderApp::ArtsBuilderApp()
 {
 	start();
 }
 
+ArtsBuilderApp::ArtsBuilderApp(QString filename)
+{
+	start();
+	if (QFile::exists(filename))
+	{
+		moduleview->open(filename);
+	} else {
+		KMessageBox::sorry( 0, 
+			i18n("The specified file does not exist."),
+			i18n("Arts Warning"));
+	}
+}
+
 void ArtsBuilderApp::start()
 {
-	printf("PORT: moduleview\n");
+	arts_debug("PORT: moduleview");
 	moduleview = new ModuleView("main");
 
-	printf("PORT: moduleview ok \n");
+	arts_debug("PORT: moduleview ok");
 	moduleview->resize(680,500);
-	moduleview->setCaption(i18n("Module View"));
-	printf("PORT: moduleview show \n");
+	arts_debug("PORT: moduleview show");
 	moduleview->show();
-	printf("PORT: moduleview show ok\n");
+	arts_debug("PORT: moduleview show ok");
 #if 0 /* PORT */
 	ArtsCorba::ModuleBroker_var ModuleBroker = theSynthesizer->moduleBroker();
 	assert(ModuleBroker);
@@ -1250,13 +1469,18 @@ void ArtsBuilderApp::end()
 {
 	delete moduleview;
 
-	printf(">>>>>decref now\n");
+	arts_debug(">>>>>decref now");
 	fflush(stdout);
-	printf("<<<<<decref ok\n");
+	arts_debug("<<<<<decref ok");
 	fflush(stdout);
 }
 
 
+static KCmdLineOptions options[] = 
+{
+	{ "+[file]", I18N_NOOP("Optional .arts file to be loaded."), 0 },
+	{ 0, 0, 0 }
+};
 
 #ifdef COMMON_BINARY
 int artsbuilder_main(int argc, char **argv)
@@ -1264,12 +1488,42 @@ int artsbuilder_main(int argc, char **argv)
 int main(int argc, char **argv)
 #endif
 {
-	KCmdLineArgs::init(argc, argv, "artsbuilder", 
-		I18N_NOOP("Arts synthesizer designer"), "0.4.0 alpha" );
+	KAboutData aboutData("artsbuilder",
+						 I18N_NOOP("artsbuilder"),
+						 "0.4.0",
+						 I18N_NOOP("Arts synthesizer designer"),
+						 KAboutData::License_GPL,
+						 "(C) 1998-2000, Stefan Westerfeld",
+						 I18N_NOOP("The analog real-time synthesizer graphical design tool."),
+						 "http://www.arts-project.org/",
+						 "submit@bugs.kde.org");
 
+	aboutData.addAuthor( "Stefan Westerfeld", I18N_NOOP( "Author" ), "stefan@twc.de" );
+	aboutData.addCredit("Jens Hahn", 0, "Jens.Hahn@t-online.de");
+	aboutData.addCredit("Martin Lorenz", 0, "lorenz@ch.tum.de");
+	aboutData.addCredit("Waldo Bastian", 0, "bastian@kde.org");
+	aboutData.addCredit("Jeff Tranter", 0, "tranter@pobox.com");
+
+	KCmdLineArgs::init(argc, argv, &aboutData);
+	KCmdLineArgs::addCmdLineOptions(options);
 	Arts::QIOManager iomanager;
 	Arts::Dispatcher dispatcher(&iomanager);
-	ArtsBuilderApp Application;
 
-	return Application.exec();
+	Arts::ObjectManager::the()->provideCapability("kdegui");
+
+	// check for one optional filename argument
+	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+	if (args->count() > 1) {
+		args->usage("");
+	}
+	if (args->count() > 0)
+	{
+		ArtsBuilderApp Application(QFile::decodeName(args->arg(0)));
+		args->clear();
+		return Application.exec();
+	} else {
+		ArtsBuilderApp Application;
+		args->clear();
+		return Application.exec();
+	}
 }
