@@ -34,6 +34,9 @@
 #include <kiconloader.h>
 #include <qlined.h>
 #include <stdio.h>
+#include <arts/debug.h>
+
+using namespace std;
 
 PortPosDlg::PortPosDlg(QWidget *parent, Structure *structure) :QDialog(parent,"Props", TRUE)
 {
@@ -146,7 +149,7 @@ PortPosDlg::PortPosDlg(QWidget *parent, Structure *structure) :QDialog(parent,"P
 void PortPosDlg::raise()
 {
 	int i = listbox->currentItem();
-	printf("selected %d\n",i);
+	arts_debug("selected %d",i);
 	if(i < 0) return;
 
 	StructurePort *port = listports[i];
@@ -165,7 +168,7 @@ void PortPosDlg::raise()
 void PortPosDlg::lower()
 {
 	int i = listbox->currentItem();
-	printf("selected %d\n",i);
+	arts_debug("selected %d",i);
 	if(i < 0) return;
 	StructurePort *port = listports[i];
 	assert(port);
@@ -182,7 +185,7 @@ void PortPosDlg::lower()
 void PortPosDlg::rename()
 {
 	int i = listbox->currentItem();
-	printf("selected %d\n",i);
+	arts_debug("selected %d",i);
 	if(i < 0) return;
 	StructurePort *port = listports[i];
 	assert(port);
@@ -192,7 +195,7 @@ void PortPosDlg::rename()
 
 	if(nd->exec())
 	{
-		printf("rename OK...\n");
+		arts_debug("rename OK...");
 		port->rename(nd->name());
 	}
 	delete nd;
@@ -229,7 +232,7 @@ void PortPosDlg::update()
 				StructurePort *port = (StructurePort *)component;
 				if(port->port()->direction == finddirection)
 				{
-					printf("port %s position %ld\n",port->name(),port->position());
+					arts_debug("port %s position %ld",port->name(),port->position());
 					pmap[port->position()] = port;
 					pcount++;
 				}
@@ -238,10 +241,13 @@ void PortPosDlg::update()
 		for(int i=0;i<pcount;i++)
 		{
 			StructurePort *port = pmap[i];
-			assert(port);
-			listbox->insertItem(port->name(),listports.size());
-			listports.push_back(port);
-			printf("listports.size() is now %d\n",listports.size());
+			if (port)
+			{
+				assert(port);
+				listbox->insertItem(port->name(),listports.size());
+				listports.push_back(port);
+				arts_debug("listports.size() is now %d",listports.size());
+			}
 		}
 	}
 	listbox->repaint();
