@@ -32,6 +32,9 @@
 #include <qlined.h>
 #include <stdio.h>
 #include <algorithm>
+#include <ctype.h> 
+
+using namespace std;
 
 static void min_size(QWidget *w) {
   w->setMinimumSize(w->sizeHint());
@@ -49,17 +52,7 @@ PortPropDlg::PortPropDlg(QWidget *parent, ModulePort *port) :QDialog(parent,"Pro
 	if(port->PortDesc.hasValue())
 		newconntype = ctValue;
 	
-	newconnvalue = 0.0;
-	newstrvalue = "";
-	isString = (port->PortDesc.type().dataType == Arts::string_data);
-
-	if(port->PortDesc.hasValue())
-	{
-		if(isString)
-			newstrvalue = port->PortDesc.stringValue().c_str();
-		else
-			newconnvalue = port->PortDesc.floatValue();
-	}
+	newvalue = "";
 
 	setCaption(i18n("Arts port properties"));
 
@@ -156,16 +149,33 @@ PortPropDlg::PortPropDlg(QWidget *parent, ModulePort *port) :QDialog(parent,"Pro
 
 	valueedit = new QLineEdit(this);
 
-	if(isString)
+	if(port->PortDesc.hasValue())
 	{
-		valueedit->setText(newstrvalue);
-	}
-	else
-	{
-		QString text;
-		text.sprintf("%2.4f",newconnvalue);
-		valueedit->setText(text);
+		Arts::Any value = port->PortDesc.value();
+		Arts::Buffer b;
+		b.write(value.value);
+
+		if(value.type == "float")
+			newvalue.sprintf("%2.4f", b.readFloat());
+		else if(value.type == "long")
+			newvalue.sprintf("%ld", b.readLong());
+		else if(value.type == "string")
+		{
+			string s;
+			b.readString(s);
+			newvalue = s.c_str();
+		}
+		else if(value.type == "boolean")
+		{
+			if(b.readBool())
+				newvalue = "true";
+			else
+				newvalue = "false";
+		}
+		else newvalue = ("*unknown type* " + value.type).c_str();
 	}
+	valueedit->setText(newvalue);
+
 	min_size(valueedit);
 	connect(valueedit, SIGNAL( textChanged(const QString&) ),
 	                   SLOT( connvalue_changed(const QString&) ));
@@ -201,7 +211,8 @@ PortPropDlg::PortPropDlg(QWidget *parent, ModulePort *port) :QDialog(parent,"Pro
 	buttonlayout->addSpacing(5);
 	KButtonBox *bbox = new KButtonBox(this);
 
-	bbox->addButton(i18n("Help"));
+	QButton *helpbutton = bbox->addButton(i18n("Help"));
+	connect( helpbutton, SIGNAL( clicked() ), SLOT(showHelp()));
 	bbox->addStretch(1);
 
 	QButton *okbutton = bbox->addButton(i18n("Okay"));
@@ -262,12 +273,27 @@ void PortPropDlg::conn_none()
 	updatestatus();
 }
 
-void PortPropDlg::connvalue_changed(const QString& newvalue)
+void PortPropDlg::connvalue_changed(const QString& _newvalue)
 {
-	newstrvalue = newvalue.ascii();
-	newconnvalue = newvalue.toFloat();
-	printf("changed: newconnvalue = %2.2f\n",newconnvalue);
-	// TODO: error handling
+	newvalue = _newvalue;
+}
+
+void PortPropDlg::showHelp()
+{
+	// transforms port->owner->name() to an anchor for the right documentation
+	// example: "Arts::Synth_MULTI_ADD" => "MREF-SYNTH-MULTI-ADD"
+	string s = port->owner->name();
+	string anchor = "MREF-";
+
+	string::iterator si = s.begin();
+	if(strncmp(s.c_str(),"Arts::",6) == 0) si += 6;
+
+	while(si != s.end())
+	{
+		if(*si == '_') anchor += '-'; else anchor += toupper(*si);
+		si++;
+	}
+	kapp->invokeHelp(anchor.c_str());
 }
 
 void PortPropDlg::apply_changes()
@@ -280,14 +306,30 @@ void PortPropDlg::apply_changes()
 
 	if(newconntype == ctValue)
 	{
-		if(isString)
-			port->PortDesc.stringValue(newstrvalue.ascii());
-		else
-			port->PortDesc.floatValue(newconnvalue);
+		string type = port->PortDesc.type().dataType;
+
+		Arts::Any a;
+		a.type = type;
+		Arts::Buffer b;
+		if(type == "float")
+			b.writeFloat(newvalue.toFloat());
+		else if(type == "long")
+			b.writeLong(newvalue.toLong());
+		else if(type == "string")
+			b.writeString(newvalue.ascii());
+		else if(type == "boolean")
+		{
+			b.writeBool(newvalue.upper() == "TRUE" || newvalue.upper() == "T"
+					  || newvalue == "1");
+		}
+
+		if(b.size() > 0)
+		{
+			b.read(a.value, b.size());
+			port->PortDesc.value(a);
+		}
 	}
 
 	if(newconntype == ctNone)
 		port->PortDesc.hasValue(false);
-
-	printf("applied: newconnvalue = %2.2f\n",newconnvalue);
 }
