@@ -31,6 +31,7 @@
 #include <kapp.h>
 #include <stdio.h>
 #include <set>
+#include <arts/debug.h>
 
 #ifndef KDE_USE_FINAL
 static void min_size(QWidget *w) {
@@ -71,7 +72,7 @@ RetrieveDlg::RetrieveDlg(QWidget *parent) :QDialog(parent,"X", TRUE)
 	listbox = new QListBox(this);
     listbox->setMinimumSize(300,200);
 
-	printf("TODO:PORT:get available structures\n");
+	arts_debug("TODO:PORT:get available structures");
 #if 0
 	// sort the result:
 	vector<StructureDesc> *structures = Synthesizer->publishedStructures();
