@@ -21,6 +21,7 @@
 
 #include "scomponent.h"
 #include <stdio.h>
+#include <arts/debug.h>
 
 StructureComponent::StructureComponent(StructureCanvas *canvas)
 {
@@ -29,5 +30,5 @@ StructureComponent::StructureComponent(StructureCanvas *canvas)
 
 StructureComponent::~StructureComponent()
 {
-	printf("gone...\n"); // FIXME: debugging required? here?
+	arts_debug("gone..."); // FIXME: debugging required? here?
 }
