@@ -22,7 +22,11 @@
 #include "structure.h"
 #include "soundserver.h"
 #include <stdio.h>
+#include <iostream.h>
 #include <fstream>
+#include <arts/debug.h>
+
+using namespace std;
 
 ExecutableStructure::ExecutableStructure()
 {
@@ -38,7 +42,7 @@ ExecutableStructure::~ExecutableStructure()
 void ExecutableStructure::stopExecute()
 {
 	assert(execID);
-	printf("TODO: PORT: freeStructure\n");
+	arts_debug("TODO: PORT: freeStructure");
 	//Synthesizer->freeStructure(execID);
 	execID = 0;
 }
@@ -46,22 +50,22 @@ void ExecutableStructure::stopExecute()
 bool ExecutableStructure::isExecuting()
 {
 	if(!execID) return(false);
-	printf("TODO:PORT:isExecuting()\n");
+	arts_debug("TODO:PORT:isExecuting()");
 	return false;
 	//return(Synthesizer->isExecuting(execID));
 }
 
 bool ExecutableStructure::saveSession(const char *filename)
 {
-	printf("TODO:PORT:saveSession()\n");
+	arts_debug("TODO:PORT:saveSession()");
 #if 0
 	assert(execID);
 
 	ArtsCorba::StringSeq_var data;
-	printf("saveSession\n");
+	arts_debug("saveSession");
 	if(Synthesizer->saveSession(execID,true,data))
 	{
-		printf("ok\n");
+		arts_debug("ok");
 		FILE *file = fopen(filename,"w");
 		if(!file) return false;
 
@@ -71,7 +75,7 @@ bool ExecutableStructure::saveSession(const char *filename)
 
 		return true;
 	}
-	printf("failed\n");
+	arts_debug("failed");
 #endif
 	return false;
 }
@@ -89,7 +93,7 @@ void Structure::setCanvas(StructureCanvas *canvas)
 Structure::~Structure()
 {
 	clear();
-	printf("~Structure (releasing structuredesc from structure)\n");
+	arts_debug("~Structure (releasing structuredesc from structure)");
 }
 
 bool Structure::startExecute()
@@ -97,13 +101,14 @@ bool Structure::startExecute()
 #if 0
 	assert(!execID);
 
-	printf("PORT: TODO startExecute()\n");
+	arts_debug("PORT: TODO startExecute()");
 	// just in case synthesis has been halted before,
 	// restart it and hope we'll have enough computing power now
 	//Synthesizer->Reset();
 	//execID = Synthesizer->createStructure(StructureDesc,preferredservers);
 	assert(execID);
 #endif
+
 	/* connect to the sound server */
 	Arts::SimpleSoundServer server;
 
@@ -124,6 +129,12 @@ bool Structure::startExecute()
 	Arts::StructureBuilder builder;
 	builder = Arts::DynamicCast(server.createObject("Arts::StructureBuilder"));
 
+	/* create a local factory - this will enable the builder to create gui qt
+	   widgets (which need to reside within an qt application to work) */
+
+	Arts::LocalFactory factory;
+	builder.addFactory(factory);
+	
 	/* create the structure on the server */
 	structure = Arts::DynamicCast(builder.createObject(remoteSD));
 	structure.start();
@@ -138,7 +149,7 @@ void Structure::stopExecute()
 
 void Structure::publish()
 {
-	printf("PORT: TODO publish()\n");
+	arts_debug("PORT: TODO publish()");
 	//Synthesizer->publishStructureDesc(StructureDesc);
 }
 
@@ -157,12 +168,14 @@ void Structure::rename(const char *newname)
 	StructureDesc.name(newname);
 }
 
-void Structure::save(const char *filename)
+bool Structure::save(const char *filename)
 {
 	vector<string> *savePtr = StructureDesc.saveToList();
 	vector<string>& list = *savePtr;
 
 	FILE *file = fopen(filename,"w");
+	if (!file)
+		return false;
 
 	vector<string>::iterator i;
 
@@ -171,13 +184,14 @@ void Structure::save(const char *filename)
 	fclose(file);
 
 	delete savePtr;
+	return true;
 }
 
 void Structure::clear()
 {
 	list<StructureComponent *>::iterator ci;
 
-	printf("clc\n");
+	arts_debug("clc");
 /*
 	for(ci = ComponentList.begin(); ci != ComponentList.end(); ci++)
 		delete (*ci);
@@ -189,7 +203,7 @@ void Structure::clear()
 		(*ci)->setSelected(true);
 	deleteSelected();
 
-	printf("sdc\n");
+	arts_debug("sdc");
 	// shouldn't do much, now that we deleted every single component of
 	// the structure, but we to it anyway, just to be sure.
 	StructureDesc.clear();
@@ -197,21 +211,21 @@ void Structure::clear()
 
 void Structure::retrieve(const char *pubname)
 {
-	printf("PORT: TODO: retrieve\n");
+	arts_debug("PORT: TODO: retrieve");
 #if 0
-	printf("retrieve... %s\n",pubname);
+	arts_debug("retrieve... %s",pubname);
 	ArtsCorba::StructureDesc_var psd = Synthesizer->lookupStructureDesc(pubname);
 
-	printf("psdlookup ok\n");
+	arts_debug("psdlookup ok");
 	if(psd)
 	{
-		printf("starting savetolist\n");
+		arts_debug("starting savetolist");
 		ArtsCorba::StringSeq_var strseq=psd->saveToList();
-		printf("savetolist ok\n");
+		arts_debug("savetolist ok");
 		loadFromList(strseq);
-		printf("loadfromlist ok\n");
+		arts_debug("loadfromlist ok");
 	}
-	printf("retrieve... ok\n");
+	arts_debug("retrieve... ok");
 #endif
 }
 
@@ -243,9 +257,9 @@ void Structure::load(const char *filename)
 	}
 	fclose(infile);
 
-	printf(">>loadfromlist...\n");
+	arts_debug(">>loadfromlist...");
 	loadFromList(strseq);
-	printf("<<loadfromlist...\n");
+	arts_debug("<<loadfromlist...");
 #endif
 }
 
@@ -253,9 +267,9 @@ void Structure::loadFromList(const vector<string>& strseq)
 {
 	assert(canvas);
 
-	printf(">>clear\n");
+	arts_debug(">>clear");
 	clear();
-	printf("<<clear\n");
+	arts_debug("<<clear");
 
 	StructureDesc.loadFromList(strseq);
 
@@ -298,7 +312,7 @@ Module *Structure::createModule(const Arts::ModuleInfo& minfo)
 StructurePort *Structure::createStructurePort(const Arts::PortType& type)
 {	// TODO:PORT: verify this code
 #if 0
-	printf("TODO:PORT:createStructurePort\n");
+	arts_debug("TODO:PORT:createStructurePort");
 #endif
 // portname generation
 	unsigned long portindex = 1,l,baselen;;
@@ -329,7 +343,7 @@ StructurePort *Structure::createStructurePort(const Arts::PortType& type)
 	delete sps;
 
 	sprintf(name,"%s%ld",namebase.c_str(),portindex);
-	printf("new Portname: %s\n",name);
+	arts_debug("new Portname: %s",name);
 	Arts::StructurePortDesc spd =
 		StructureDesc.createStructurePortDesc(type,name);
 
@@ -362,7 +376,7 @@ long Structure::countSelected()
 
 void Structure::deleteSelected()
 {
-	printf("deleteSelected...\n");
+	arts_debug("deleteSelected...");
 
 	// remove module from the ModuleList
 	list<Module *>::iterator mi;
@@ -391,7 +405,7 @@ void Structure::deleteSelected()
 		else ci++;
 	}
 
-	printf("deleteSelected ok.\n");
+	arts_debug("deleteSelected ok.");
 }
 
 StructureComponent *Structure::componentAt(long x, long y, bool ignore_selected)
