@@ -34,7 +34,7 @@ public:
 	void streamInit()
 	{
 		for(unsigned long i=0;i<4096;i++)
-			noise[i] = (float)rand()/(float)RAND_MAX;
+			noise[i] = ((float)rand()/(float)RAND_MAX)*2.0-1.0;
 		pos = 0;
 	}
 	void calculateBlock(unsigned long samples)
