@@ -33,6 +33,8 @@
 #include <klocale.h>
 #include <kapp.h>
 
+using namespace std;
+
 static void min_size(QWidget *w) {
   w->setMinimumSize(w->sizeHint());
 } 
@@ -110,7 +112,7 @@ ChooseBusDlg::ChooseBusDlg(QWidget *parent) :QDialog(parent,"X", TRUE)
 	QButton *cancelbutton = bbox->addButton(i18n("Cancel"));
 	connect( cancelbutton, SIGNAL( clicked() ), SLOT(reject() ) );
 
-	QButton *okbutton = bbox->addButton(i18n("Okay"));
+	QButton *okbutton = bbox->addButton(i18n("OK"));
 	connect( okbutton, SIGNAL( clicked() ), SLOT(accept() ) );
 
 	bbox->layout();
