@@ -24,9 +24,10 @@
 #include "kdisptext.h"
 #include <qpainter.h>
 #include <qfont.h>
-#include <qfontmet.h>
-#include <qscrbar.h>
-#include <kapp.h>
+#include <qfontmetrics.h>
+#include <qrect.h>
+#include <kglobal.h>
+#include <kinstance.h>
 #include <kconfig.h>
 #include "version.h"
 
@@ -34,157 +35,144 @@
 #define NUMPREVLINES 2
 
 
-KDisplayText::KDisplayText(QWidget *parent,const char *name) : QWidget(parent,name)
+KDisplayText::KDisplayText(QWidget *parent,const char *name) : QScrollView(parent,name)
 {
-    first_line_[0]=first_line_[1]=NULL;
-    linked_list_[0]=linked_list_[1]=NULL;
-    cursor_line_[0]=cursor_line_[1]=NULL;
-    cursor_[0]=cursor_[1]=NULL;
-    nlines_[0]=nlines_[1]=0;
-    linked_list=NULL;
-    cursor_line=NULL;
-    first_line=NULL;
-    cursor=NULL;
-    textscrollbar=NULL;
-    nlines=0;
-    setBackgroundColor(QColor (110,110,110));
-    KConfig *kcfg=(KApplication::getKApplication())->getConfig();
-    kcfg->setGroup("KMid");
-    QFont *qtextfontdefault=new QFont("courier",22);
-    qtextfont=new QFont(kcfg->readFontEntry("KaraokeFont",qtextfontdefault));
-    delete qtextfontdefault;
-    qfmetr=new QFontMetrics(*qtextfont);
-    font_height=qfmetr->height();
-    qpaint=NULL;
-    nvisiblelines=height()/qfmetr->lineSpacing();
-    textscrollbar=new QScrollBar(1,1,1,2,1,QScrollBar::Vertical,this,"TheKaraokeScrollBar");
-    connect(textscrollbar,SIGNAL(valueChanged(int)),this,SLOT(ScrollText(int)));
-};
+  first_line_[0]=first_line_[1]=NULL;
+  linked_list_[0]=linked_list_[1]=NULL;
+  cursor_line_[0]=cursor_line_[1]=NULL;
+  cursor_[0]=cursor_[1]=NULL;
+  nlines_[0]=nlines_[1]=0;
+  linked_list=NULL;
+  cursor_line=NULL;
+  first_line=NULL;
+  cursor=NULL;
+  nlines=0;
+  viewport()->setBackgroundColor(QColor (110,110,110));
+//  setBackgroundMode(NoBackground);
+  KConfig *kcfg=KGlobal::instance()->config();
+  kcfg->setGroup("KMid");
+  typeoftextevents=kcfg->readNumEntry("TypeOfTextEvents",1);
+  QFont *qtextfontdefault=new QFont("courier",22);
+  qtextfont=new QFont(kcfg->readFontEntry("KaraokeFont",qtextfontdefault));
+  delete qtextfontdefault;
+  qfmetr=new QFontMetrics(*qtextfont);
+  nvisiblelines=height()/qfmetr->lineSpacing();
+  autoscrollv=0;
+}
 
 KDisplayText::~KDisplayText()
 {
-    RemoveLinkedList();
-    //if (textscrollbar!=NULL) delete textscrollbar;
-};
+  RemoveLinkedList();
+}
 
 void KDisplayText::PreDestroyer(void)
 {
-    delete qfmetr;
-    delete qtextfont;
-    if (qpaint!=NULL) delete qpaint;
-};
+  delete qfmetr;
+  delete qtextfont;
+}
 
 void KDisplayText::RemoveLine(kdispt_line *tmpl)
 {
-    kdispt_ev *tmpe;
-    while (tmpl->ev!=NULL)
-    {
-        tmpe=tmpl->ev;
-        tmpl->ev=tmpe->next;
-        //    delete tmpe->spev; Remember that the Special Events that this pointer
-        //		 pointers to is the same that the Player object has instantiated
-        delete tmpe;
-    };
-};
+  kdispt_ev *tmpe;
+  while (tmpl->ev!=NULL)
+  {
+    tmpe=tmpl->ev;
+    tmpl->ev=tmpe->next;
+    //    delete tmpe->spev; Remember that the Special Events that this pointer
+    //		 pointers to is the same that the Player object has instantiated
+    delete tmpe;
+  }
+}
 
 void KDisplayText::RemoveLinkedList(void)
 {
-    cursor=NULL;
-    cursor_line=NULL;
-    first_line=NULL;
-    linked_list=NULL;
-    nlines=0;
-    nlines_[0]=nlines_[1]=0;
-    first_line_[0]=first_line_[1]=NULL;
-    cursor_line_[0]=cursor_line_[1]=NULL;
-    cursor_[0]=cursor_[1]=NULL;
-    
-    kdispt_line *tmpl;
-    for (int i=0;i<2;i++)
+  cursor=NULL;
+  cursor_line=NULL;
+  first_line=NULL;
+  linked_list=NULL;
+  nlines=0;
+  nlines_[0]=nlines_[1]=0;
+  first_line_[0]=first_line_[1]=NULL;
+  cursor_line_[0]=cursor_line_[1]=NULL;
+  cursor_[0]=cursor_[1]=NULL;
+
+  kdispt_line *tmpl;
+  for (int i=0;i<2;i++)
+  {
+    while (linked_list_[i]!=NULL)
     {
-        while (linked_list_[i]!=NULL)
-        {
-            RemoveLine(linked_list_[i]);
-            tmpl=linked_list_[i];
-            linked_list_[i]=linked_list_[i]->next;
-            delete tmpl;
-        };
-    };
-};
+      RemoveLine(linked_list_[i]);
+      tmpl=linked_list_[i];
+      linked_list_[i]=linked_list_[i]->next;
+      delete tmpl;
+    }
+  }
+}
 
 void KDisplayText::ClearEv(bool totally)
 {
-    RemoveLinkedList();
-    if (totally)
-    {
-        textscrollbar->setRange(1,1);
-        repaint(TRUE);
-    };
-};
+  RemoveLinkedList();
+  if (totally)
+  {
+    killTimers();
+    autoscrollv=0;
+    resizeContents(0,0);
+    viewport()->repaint(TRUE);
+  }
+}
 
 int KDisplayText::IsLineFeed(char c,int type)
 {
-    switch (type)
-    {
+  switch (type)
+  {
     case (1) : if (/*(c==0)||*/(c=='\\')||(c=='/')||(c=='@')) return 1;break;
     case (5) : if (/*(c==0)||*/(c==10)||(c==13)) return 1;break;
     default :  if ((c==0)||(c==10)||(c==13)||(c=='\\')||(c=='/')||(c=='@')) return 1;break;
-    };
-    return 0;
-};
+  }
+  return 0;
+}
 
 void KDisplayText::AddEv(SpecialEvent *ev)
 {
-    if ((ev->type==1) || (ev->type==5))
+  if ((ev->type==1) || (ev->type==5))
+  {
+    int idx=(ev->type==1)? 0 : 1;
+    if (linked_list_[idx]==NULL)
     {
-        int idx=(ev->type==1)? 0 : 1;
-        if (linked_list_[idx]==NULL)
-        {
-            linked_list_[idx]=new kdispt_line;
-            linked_list_[idx]->next=NULL;
-            linked_list_[idx]->num=1;
-            linked_list_[idx]->ypos=30;
-            linked_list_[idx]->ev=new kdispt_ev;
-            cursor_line_[idx]=linked_list_[idx];
-            cursor_[idx]=cursor_line_[idx]->ev;
-            cursor_[idx]->spev=ev;
-            cursor_[idx]->xpos=5;
-            if (IsLineFeed(ev->text[0],ev->type))
-                cursor_[idx]->width=qfmetr->width(&ev->text[1]);
-            else
-                cursor_[idx]->width=qfmetr->width(ev->text);
-            cursor_[idx]->next=NULL;    
-            first_line_[idx]=linked_list_[idx];
-            first_line=first_line_[idx];
-            nlines_[idx]=1;
-        }
-        else
-        {
-            if (IsLineFeed(ev->text[0],ev->type))
-            {
-                nlines_[idx]++;
-                cursor_line_[idx]->next=new kdispt_line;
-                cursor_line_[idx]=cursor_line_[idx]->next;
-                cursor_line_[idx]->num=nlines_[idx];
-                cursor_line_[idx]->ypos=cursor_line_[idx]->num*30;
-                cursor_line_[idx]->ev=new kdispt_ev;
-                cursor_line_[idx]->next=NULL;
-                cursor_[idx]=cursor_line_[idx]->ev;
-                cursor_[idx]->xpos=5;
-                cursor_[idx]->width=qfmetr->width(&ev->text[1]);
-            }
-            else
-            {
-                cursor_[idx]->next=new kdispt_ev;
-                cursor_[idx]->next->xpos=cursor_[idx]->xpos+cursor_[idx]->width;
-                cursor_[idx]=cursor_[idx]->next;
-                cursor_[idx]->width=qfmetr->width(ev->text);
-            };
-            cursor_[idx]->spev=ev;
-            cursor_[idx]->next=NULL;
-        };
-    };
-};
+      linked_list_[idx]=new kdispt_line;
+      linked_list_[idx]->next=NULL;
+      linked_list_[idx]->num=1;
+      linked_list_[idx]->ev=new kdispt_ev;
+      cursor_line_[idx]=linked_list_[idx];
+      cursor_[idx]=cursor_line_[idx]->ev;
+      cursor_[idx]->spev=ev;
+      cursor_[idx]->next=NULL;    
+      first_line_[idx]=linked_list_[idx];
+      first_line=first_line_[idx];
+      nlines_[idx]=1;
+    }
+    else
+    {
+      if (IsLineFeed(ev->text[0],ev->type))
+      {
+	nlines_[idx]++;
+	cursor_line_[idx]->next=new kdispt_line;
+	cursor_line_[idx]=cursor_line_[idx]->next;
+	cursor_line_[idx]->num=nlines_[idx];
+	cursor_line_[idx]->ev=new kdispt_ev;
+	cursor_line_[idx]->next=NULL;
+	cursor_[idx]=cursor_line_[idx]->ev;
+      }
+      else
+      {
+	cursor_[idx]->next=new kdispt_ev;
+	cursor_[idx]=cursor_[idx]->next;
+      }
+      cursor_[idx]->spev=ev;
+      cursor_[idx]->next=NULL;
+    }
+  }
+}
 
 void KDisplayText::calculatePositions(void)
 {
@@ -192,12 +180,16 @@ void KDisplayText::calculatePositions(void)
     int fin=0;
     kdispt_line *tmpl;
     kdispt_ev *tmp;
-    int tmpx;
-    int tmpy;
+    int tmpx=0;
+    int tmpy=0;
+    int tmpw=0;
+    int maxx=0;
+    nlines=nlines_[(typeoftextevents==1)? 0:1];
     while (!fin)
     {
         tmpl=linked_list_[(typeoftextevents==1)?0:1];
-        tmpy=30;
+        tmpy=qfmetr->lineSpacing();
+        maxx=0;
         while (tmpl!=NULL)
         {
             tmp=tmpl->ev;
@@ -208,58 +200,79 @@ void KDisplayText::calculatePositions(void)
                 {
                     if (IsLineFeed(tmp->spev->text[0],typeoftextevents))
                     {
-                        tmpy+=30;
+                        tmpy+=qfmetr->lineSpacing();
                         tmpx=5;
+
                         tmp->xpos=tmpx;
-                        if (tmp->spev->text[0]!=0) tmp->width=qfmetr->width(&tmp->spev->text[1]);
+                        if (tmp->spev->text[0]!=0) tmpw=qfmetr->width(&tmp->spev->text[1]);
+				else tmpw=0;
+                        tmp->r=qfmetr->boundingRect(&tmp->spev->text[1]);
                     }
                     else
                     {
                         tmp->xpos=tmpx;
-                        tmp->width=qfmetr->width(tmp->spev->text);
-                    };
-                    tmpx+=tmp->width;
-                };
+                        tmpw=qfmetr->width(tmp->spev->text);
+                        tmp->r=qfmetr->boundingRect(tmp->spev->text);
+                    }
+                    tmp->r.moveBy(tmpx,tmpy);
+                    tmpx+=tmpw;
+		    if (tmpx>maxx) maxx=tmpx;
+                }
                 tmp=tmp->next;
-            };
-            tmpl->ypos=tmpy;
+            }
+            tmpl->ypos=tmpl->num*qfmetr->lineSpacing();
+            tmpy=tmpl->ypos;
             tmpl=tmpl->next;
-        };
-        
+        }
+        maxX[(typeoftextevents==1)?0:1]=maxx+10;
+        maxY[(typeoftextevents==1)?0:1]=nlines_[(typeoftextevents==1)?0:1]*qfmetr->lineSpacing()+
+				qfmetr->descent()+10;
+ 
         if (typeoftextevents==1) typeoftextevents=5;
         else fin=1;
-    };
-    
+    }
+
+}
+
+kdispt_line *KDisplayText::searchYOffset(int y, kdispt_line *start)
+{
+kdispt_line *t=start;
+while (t!=NULL)
+   {
+   if (t->ypos+qfmetr->descent()>y) return start;
+   start=t;
+   t=t->next;
+   };
+return start;
 };
 
-void KDisplayText::paintEvent(QPaintEvent *)
+void KDisplayText::drawContents(QPainter *p,int clipx,int clipy,int clipw,int cliph)
 {
-    if (qpaint==NULL)
-    {
-        qpaint=new QPainter(this);
-        qpaint->setFont(*qtextfont);
-    };
-    if (linked_list==NULL) {drawFrame();return;};
-    if (nlines>nvisiblelines)
-        textscrollbar->setRange(1,nlines-nvisiblelines+1);
-    else
-        textscrollbar->setRange(1,1);
-    
+    p->setFont(*qtextfont);
+    if (linked_list==NULL) return;
     int i=0;
-    qpaint->setPen(QColor(255,255,0));
+    p->setPen(yellow);
     int colorplayed=1;
     if (cursor==NULL) colorplayed=0; // Thus, the program doesn't change the color
-    kdispt_line *tmpl=first_line;
+    kdispt_line *tmpl=linked_list;
     kdispt_ev *tmp;
-    KConfig *kcfg=KApplication::getKApplication()->getConfig();
-    kcfg->setGroup("KMid");
-    typeoftextevents=kcfg->readNumEntry("TypeOfTextEvents",1);
+
 #ifdef KDISPTEXTDEBUG
     printf("events displayed %d\n",typeoftextevents);
 #endif
-    while ((i<nvisiblelines)&&(tmpl!=NULL))
+
+    tmpl=searchYOffset(clipy,linked_list);
+    int nlinestodraw=1;
+    kdispt_line *t=tmpl;
+    while ((t!=NULL)&&(t->ypos+qfmetr->descent()<clipy+cliph))
+       {
+       nlinestodraw++;
+       t=t->next;
+       }
+    
+    i=0;
+    while ((i<nlinestodraw)&&(tmpl!=NULL))
     {
-        tmpl->ypos=(tmpl->num-first_line->num+1)*qfmetr->lineSpacing();
         tmp=tmpl->ev;
         while ((tmp!=NULL)&&(tmp->spev->type!=typeoftextevents)) tmp=tmp->next;
         while (tmp!=NULL)
@@ -268,61 +281,41 @@ void KDisplayText::paintEvent(QPaintEvent *)
                  //	(tmp->spev->absmilliseconds>=cursor->spev->absmilliseconds))
                  (tmp->spev->id>=cursor->spev->id))
             {
-                qpaint->setPen(QColor(0,0,0));
+                p->setPen(black);
                 colorplayed=0;
-            };	
+            }	
             
             if (IsLineFeed(tmp->spev->text[0],tmp->spev->type))
-                qpaint->drawText(tmp->xpos,tmpl->ypos,&tmp->spev->text[1]);
+                p->drawText(tmp->xpos,tmpl->ypos,&tmp->spev->text[1]);
             else
-                qpaint->drawText(tmp->xpos,tmpl->ypos,tmp->spev->text);
+                p->drawText(tmp->xpos,tmpl->ypos,tmp->spev->text);
             tmp=tmp->next;
             while ((tmp!=NULL)&&(tmp->spev->type!=typeoftextevents)) tmp=tmp->next;
-        };
+        }
         i++;
         tmpl=tmpl->next;
     }
     
-    drawFrame();
+}
 
-    qpaint->setPen(QColor(255,255,0));
-    
-};
 
-void KDisplayText::drawFrame(void)
+void KDisplayText::resizeEvent(QResizeEvent *e)
 {
-    int w=width();
-    if (textscrollbar!=0L) w=textscrollbar->x();
-    QColorGroup qcg=colorGroup();
-    qpaint->setPen(qcg.light());
-    qpaint->drawLine(0,height()-1,w-1,height()-1);
-    qpaint->drawLine(w-1,0,w-1,height()-1);
-    qpaint->setPen(qcg.background());
-    qpaint->drawLine(1,height()-2,w-2,height()-2);
-    qpaint->drawLine(w-2,1,w-2,height()-2);
-    qpaint->setPen(qcg.mid());
-    qpaint->drawLine(0,0,0,height()-1);
-    qpaint->drawLine(0,0,w-1,0);
-    qpaint->setPen(qcg.dark());
-    qpaint->drawLine(1,1,1,height()-2);
-    qpaint->drawLine(1,1,w-2,1);
-//    qpaint->setPen(QColor(0,0,0));
-//    qpaint->drawRect(2,2,w-4,height()-4);
+    QScrollView::resizeEvent(e);  
+    nvisiblelines=visibleHeight()/qfmetr->lineSpacing();
+    if ( (nlines>nvisiblelines) || (nvisiblelines==0) )
+        resizeContents(maxX[(typeoftextevents==1)?0:1],maxY[(typeoftextevents==1)?0:1]);
+    else
+        resizeContents(0,0);
 
-};
-
-void KDisplayText::resizeEvent(QResizeEvent *)
-{
-    nvisiblelines=height()/qfmetr->lineSpacing();
-    
-    textscrollbar->setGeometry(width()-16,0,16,height());
-};
+}
 
 void KDisplayText::CursorToHome(void)
 {
-    KConfig *kcfg=KApplication::getKApplication()->getConfig();
+/*    KConfig *kcfg=KGlobal::instance()->config();
     kcfg->setGroup("KMid");
     typeoftextevents=kcfg->readNumEntry("TypeOfTextEvents",1);
+*/
     linked_list=linked_list_[(typeoftextevents==1)? 0:1];
     nlines=nlines_[(typeoftextevents==1)? 0:1];
     cursor_line_[0]=linked_list_[0];
@@ -343,68 +336,81 @@ void KDisplayText::CursorToHome(void)
         cursor_line=linked_list;
         cursor=cursor_line->ev;
         first_line=linked_list;
-    };
+    }
+
+    nvisiblelines=visibleHeight()/qfmetr->lineSpacing();
+    if (nlines>nvisiblelines) 
+      resizeContents(maxX[(typeoftextevents==1)?0:1],maxY[(typeoftextevents==1)?0:1]);
+    else
+      resizeContents(0,0); 
+
+
+    setContentsPos(0,0);
     
-    textscrollbar->setValue(1);
-    
-}; 
+} 
 
 void KDisplayText::PaintIn(int type)
 {
-    if (type!=typeoftextevents)
+  if (type!=typeoftextevents)
+  {
+    int idx=(type==1)?0:1;
+    if (cursor_[idx]==NULL) return;
+    cursor_[idx]=cursor_[idx]->next;
+    while ((cursor_[idx]==NULL)&&(cursor_line_[idx]!=NULL))
     {
-        int idx=(type==1)?0:1;
-        if (cursor_[idx]==NULL) return;
-        cursor_[idx]=cursor_[idx]->next;
-        while ((cursor_[idx]==NULL)&&(cursor_line_[idx]!=NULL))
-        {
-            cursor_line_[idx]=cursor_line_[idx]->next;
-            if (cursor_line_[idx]!=NULL)
-            {
-                cursor_[idx]=cursor_line_[idx]->ev;
-                if ((cursor_line_[idx]->num>first_line_[idx]->num+NUMPREVLINES)
-                    &&(cursor_line_[idx]->num<first_line_[idx]->num+nvisiblelines+1))
-                    if ((first_line_[idx]!=NULL)&&(first_line_[idx]->num+nvisiblelines<=nlines_[idx])) first_line_[idx]=first_line_[idx]->next;
-            };
-        };
-        return;
-    };
-    
-    if ((cursor==NULL)||(cursor_line==NULL))
-    {
-        printf("KDispT : cursor == NULL !!!\n");
-        return;
-    };
-    
-    if ((cursor_line->num>=first_line->num)&&(cursor_line->num<first_line->num+nvisiblelines))
-    { 
-        if (cursor->spev->type==typeoftextevents)
-            if (IsLineFeed(cursor->spev->text[0],cursor->spev->type))
-                qpaint->drawText(cursor->xpos,cursor_line->ypos,&cursor->spev->text[1]);
-            else
-                qpaint->drawText(cursor->xpos,cursor_line->ypos,cursor->spev->text);
-    };
-    cursor=cursor->next;
-    while ((cursor==NULL)&&(cursor_line!=NULL))
-    {
-        cursor_line=cursor_line->next;
-        if (cursor_line!=NULL) 
-        {
-            cursor=cursor_line->ev;
-            if ((cursor_line->num>first_line->num+NUMPREVLINES)
-                &&(cursor_line->num<first_line->num+nvisiblelines+1))
-                textscrollbar->setValue(textscrollbar->value()+1);
-        };
-    };
-};
+      cursor_line_[idx]=cursor_line_[idx]->next;
+      if (cursor_line_[idx]!=NULL)
+      {
+	cursor_[idx]=cursor_line_[idx]->ev;
+	if ((cursor_line_[idx]->num>first_line_[idx]->num+NUMPREVLINES)
+	    &&(cursor_line_[idx]->num<first_line_[idx]->num+nvisiblelines+1))
+	  if ((first_line_[idx]!=NULL)&&(first_line_[idx]->num+nvisiblelines<=nlines_[idx])) first_line_[idx]=first_line_[idx]->next;
+      }
+    }
+    return;
+  }
 
-void KDisplayText::ScrollText(int i)
-{
-    kdispt_line *tmpl=linked_list;
-    while ((tmpl!=NULL)&&(tmpl->num<i)) tmpl=tmpl->next;
-    first_line=tmpl;
-    repaint();
-};
+  if ((cursor==NULL)||(cursor_line==NULL))
+  {
+    printf("KDispT : cursor == NULL !!!\n");
+    return;
+  }
+
+  if (cursor->spev->type==typeoftextevents)
+  {
+//    int x,y;
+//    contentsToViewport(cursor->xpos,cursor_line->ypos,x,y);
+
+    kdispt_ev *tmp=cursor;
+    cursor=cursor->next;
+    if (tmp!=NULL) repaintContents(tmp->r);
+
+  }
+  else 
+    cursor=cursor->next;
+
+
+  while ((cursor==NULL)&&(cursor_line!=NULL))
+  {
+    cursor_line=cursor_line->next;
+    if (cursor_line!=NULL) 
+    {
+      cursor=cursor_line->ev;
+      if ((cursor_line->ypos>contentsY()+(visibleHeight()*5/8))&&
+	  (cursor_line->ypos<contentsY()+visibleHeight()+autoscrollv))
+        {
+	bool b=(autoscrollv==0);	
+	autoscrollv+=qfmetr->lineSpacing();
+	if (b) startTimer(100);
+	else {
+	   killTimers();
+	   startTimer(100/(autoscrollv/qfmetr->lineSpacing()+1));
+	}
+	}
+//	scrollBy(0,qfmetr->lineSpacing());
+    }
+  }
+}
 
 void KDisplayText::gotomsec(ulong i)
 {
@@ -427,10 +433,10 @@ void KDisplayText::gotomsec(ulong i)
                     if ((cursor_line_[notidx]->num>first_line_[notidx]->num+NUMPREVLINES)
                         &&(cursor_line_[notidx]->num<first_line_[notidx]->num+nvisiblelines+1))
                         if ((first_line_[notidx]!=NULL)&&(first_line_[notidx]->num+nvisiblelines<=nlines_[notidx])) first_line_[notidx]=first_line_[notidx]->next;
-                };
-            };
-        };
-    };
+                }
+            }
+        }
+    }
     
     if (linked_list!=NULL) 
     {
@@ -449,37 +455,38 @@ void KDisplayText::gotomsec(ulong i)
                     if ((cursor_line->num>first_line->num+NUMPREVLINES)
                         &&(cursor_line->num<first_line->num+nvisiblelines+1))
                         if ((first_line!=NULL)&&(first_line->num+nvisiblelines<=nlines)) first_line=first_line->next;
-                };
-            };
+                }
+            }
             
             
         }
         
-        textscrollbar->setValue(first_line->num);
-        repaint();
-    };
-};
+	killTimers();
+	autoscrollv=0;
+        setContentsPos(0,first_line->ypos);
+        viewport()->repaint();
+        
+    }
+}
 
 QFont *KDisplayText::getFont(void)
 {
     return qtextfont;
-};
+}
 
 void KDisplayText::fontChanged(void)
 {
-    KConfig *kcfg=(KApplication::getKApplication())->getConfig();
+    KConfig *kcfg=KGlobal::instance()->config();
     kcfg->setGroup("KMid");
     QFont *qtextfontdefault=new QFont(*qtextfont);
     delete qtextfont;
     qtextfont=new QFont(kcfg->readFontEntry("KaraokeFont",qtextfontdefault));
     delete qtextfontdefault;
     qfmetr=new QFontMetrics(*qtextfont);
-    font_height=qfmetr->height();
-    if (qpaint!=NULL) qpaint->setFont(*qtextfont);
     calculatePositions();
     nvisiblelines=height()/qfmetr->lineSpacing();
-    repaint(TRUE);
-};
+    viewport()->repaint(TRUE);
+}
 
 void KDisplayText::ChangeTypeOfTextEvents(int type)
 {
@@ -496,38 +503,41 @@ void KDisplayText::ChangeTypeOfTextEvents(int type)
     typeoftextevents=type;
     if (first_line!=NULL) 
     {
+        nvisiblelines=height()/qfmetr->lineSpacing();
         if (nlines>nvisiblelines)
-            textscrollbar->setRange(1,nlines-nvisiblelines+1);
+            resizeContents(maxX[(typeoftextevents==1)?0:1],maxY[(typeoftextevents==1)?0:1]);
         else
-            textscrollbar->setRange(1,1);
-        textscrollbar->setValue(first_line->num);
-    };
-};
+            resizeContents(0,0);
+
+        setContentsPos(0,first_line->ypos);
+    }
+    viewport()->repaint(TRUE);
+}
 
 int KDisplayText::ChooseTypeOfTextEvents(void)
 {
     return (nlines_[0]>nlines_[1])? 1 : 5;
-};
+}
 
 void KDisplayText::ScrollDown()
 {
-    textscrollbar->setValue(textscrollbar->value()+1);
-};
+    scrollBy(0,2/**qfmetr->lineSpacing()*/);
+}
 
 void KDisplayText::ScrollUp()
 {
-    textscrollbar->setValue(textscrollbar->value()-1);
-};
+    scrollBy(0,-2/**qfmetr->lineSpacing()*/);
+}
 
 void KDisplayText::ScrollPageDown()
 {
-    textscrollbar->setValue(textscrollbar->value()+nvisiblelines);
-};
+    scrollBy(0,nvisiblelines*qfmetr->lineSpacing());
+}
 
 void KDisplayText::ScrollPageUp()
 {
-    textscrollbar->setValue(textscrollbar->value()-nvisiblelines);
-};
+    scrollBy(0,-nvisiblelines*qfmetr->lineSpacing());
+}
 
 void KDisplayText::saveLyrics(FILE *fh)
 {
@@ -543,13 +553,51 @@ void KDisplayText::saveLyrics(FILE *fh)
                 else
                     fputs(Cptr->spev->text,fh);
             Cptr=Cptr->next;
-        };
+        }
         while (Cptr!=NULL)
         {
             fputs(Cptr->spev->text,fh);
             Cptr=Cptr->next;
-        };
+        }
         fputs("\n",fh);
         Lptr=Lptr->next;
-    };
-};
+    }
+}
+
+void KDisplayText::timerEvent(QTimerEvent *e)
+{
+    int dy;
+    if (autoscrollv>0)
+    {
+    dy=2+autoscrollv/50;
+    scrollBy(0,dy);
+    autoscrollv-=dy;
+    if (autoscrollv<0) 
+	{
+	killTimer(e->timerId());
+	autoscrollv=0;
+	}
+    }
+    else
+    if (autoscrollv<0)
+    {
+//    dy=(autoscrollv<-2*qfmetr->lineSpacing())?-7:-2;
+    dy=-2+autoscrollv/50;
+    scrollBy(0,dy);
+    autoscrollv-=dy;
+    if (autoscrollv>0) 
+	{
+	killTimer(e->timerId());
+	autoscrollv=0;
+	}
+    }
+    else
+	killTimer(e->timerId());
+    
+}
+
+
+/*QSize KDisplayText::sizeHint()
+{
+return QSize(400,200);
+}*/
