@@ -169,6 +169,7 @@ kmidClient::kmidClient(QWidget *parent, KActionCollection *ac, const char *name)
     
     midi = new DeviceManager(mididev);
     midi->initManager();
+    m_kMid.midi=midi;
     player= new MidiPlayer(midi,m_kMid.pctl);
     
     kconf->setGroup("Midimapper");
@@ -251,6 +252,7 @@ kmidClient::~kmidClient()
 // Let's detach and delete shared memory
     shmdt((char *)m_kMid.pctl);
     shmctl(m_kMid.pctlsmID, IPC_RMID, 0L);
+    m_kMid.pctl=0L;
 };
 
 // Use KURL::filename ! (David)
@@ -913,13 +915,18 @@ void kmidClient::shuttingDown(void)
 
 void kmidClient::slotStop()
 {
+    if (!m_kMid.pctl) return;
+
     if (!shuttingdown)
     {
-        for (int i=0;i<16;i++) m_kMid.pctl->forcepgm[i]=FALSE;
-        if (channelView) channelView->reset();
-        tempoLCD->display(tempoToMetronomeTempo(m_kMid.pctl->tempo));
-        currentTempo=tempoLCD->getValue();
-        tempoLCD->setDefaultValue(tempoToMetronomeTempo(m_kMid.pctl->tempo)*m_kMid.pctl->ratioTempo);
+         for (int i=0;i<16;i++) m_kMid.pctl->forcepgm[i]=FALSE;
+       if (channelView) channelView->reset();
+       if (tempoLCD)
+       {
+         tempoLCD->display(tempoToMetronomeTempo(m_kMid.pctl->tempo));
+         currentTempo=tempoLCD->getValue();
+         tempoLCD->setDefaultValue(tempoToMetronomeTempo(m_kMid.pctl->tempo)*m_kMid.pctl->ratioTempo);
+       }
     }
     
     if (m_kMid.pctl->playing==0) return;
