@@ -621,7 +621,7 @@ void kmidFrame::options_KeyConfig()
    */
 }
 
-void kmidFrame::openURL( QString url )
+void kmidFrame::openURL( const QString url )
 {
   int c=autoAddSongToCollection(url.ascii(),1);
   kmidclient->setActiveCollection(c);
