@@ -99,7 +99,7 @@ public slots:
     void spacePressed();
 
 
-   virtual void openURL( QString s );
+   virtual void openURL( const QString s );
 /*   virtual void play();
    virtual void pause();
    virtual void stop();
