@@ -21,20 +21,25 @@
     or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain
 
 ***************************************************************************/
-#include "kmidframe.h"
 #include <stdlib.h>
 #include <string.h>
-#include <kapp.h>
-#include <qwidget.h>
 #include <signal.h>
-#include "version.h"
-//#include <locale.h>
+
+#include <qwidget.h>
+
+#include <kapp.h>
 #include <klocale.h>
-#include <kmsgbox.h>
+#include <kio/job.h>
+#include <kcmdlineargs.h>
+#include <kaboutdata.h>
+
+#include "kmidframe.h"
+#include "kmid_part.h"
+#include "version.h"
 
 int main(int argc, char **argv)
 {
-    printf("%s Copyright (C) 1997,98 Antonio Larrosa Jimenez. Malaga (Spain)\n",VERSION_TXT);
+    printf("%s Copyright (C) 1997,98,99,2000 Antonio Larrosa Jimenez. Malaga (Spain)\n",VERSION_TXT);
     printf("KMid comes with ABSOLUTELY NO WARRANTY; for details view file COPYING\n");
     printf("This is free software, and you are welcome to redistribute it\n");
     printf("under certain conditions\n");
@@ -49,7 +54,21 @@ int main(int argc, char **argv)
     sigaction(SIGTERM, &act, NULL);
 */
 
-    KApplication *app=new KApplication(argc,argv,"kmid");
+    KCmdLineArgs::init(argc, argv, KMidFactory::aboutData() );
+
+    static KCmdLineOptions options[] =
+    {
+       { "+file", I18N_NOOP("File to open"), 0 },
+       { 0, 0, 0}
+    };
+    KCmdLineArgs::addCmdLineOptions(options);
+
+
+
+
+    KApplication *app=new KApplication;
+
+//    KApplication *app=new KApplication(argc,argv,"kmid");
 
     kmidFrame *kmidframe=new kmidFrame("KMid");
 
@@ -58,21 +77,23 @@ int main(int argc, char **argv)
     QObject::connect(app,SIGNAL(shutDown()),kmidframe,SLOT(shuttingDown()));
 
     if (app->isRestored())
-	{
-	if (kmidframe->canBeRestored(1)) kmidframe->restore(1);
+        {
+        if (kmidframe->canBeRestored(1)) kmidframe->restore(1);
         }
 
     kmidframe->show();
 
+    //CT    KIOJob::initStatic();
+
 /*
     if (app->isRestored())
-	{
-	RESTORE(kmidFrame);
+        {
+        RESTORE(kmidFrame);
         }
        else
         {
         kmidFrame *kmidframe=new kmidFrame("KMid");
-	kmidframe->show();
+        kmidframe->show();
         };
 */
     int ret= app->exec();
@@ -81,3 +102,4 @@ int main(int argc, char **argv)
     delete app;
     return ret;
 };
+
