@@ -1,5 +1,5 @@
 /*
-	$Id: config.h,v 1.47 2000/08/23 05:51:39 waba Exp $
+	$Id: config.h,v 1.49 2001/01/19 09:17:50 coolo Exp $
 
     TiMidity -- Experimental MIDI to WAVE converter
     Copyright (C) 1995 Tuukka Toivonen <toivonen@clinet.fi>
@@ -64,6 +64,7 @@
    This is currently ignored for Win32. */
 #define DECOMPRESSOR_LIST { \
 			      ".gz", "gunzip -c %s", \
+			      ".bz2", "bzip2 -cd %s", \
 			      ".Z", "zcat %s", \
 			      ".zip", "unzip -p %s", \
 			      ".lha", "lha -pq %s", \
@@ -140,7 +141,7 @@ typedef double FLOAT_T;
 /* The size of the internal buffer is 2^AUDIO_BUFFER_BITS samples.
    This determines maximum number of samples ever computed in a row.
 
-   For Linux and FreeBSD users:
+   For Linux, FreeBSD and BSD/OS users:
    
    This also specifies the size of the buffer fragment.  A smaller
    fragment gives a faster response in interactive mode -- 10 or 11 is
@@ -226,7 +227,7 @@ typedef double FLOAT_T;
 #define MAX_CONTROL_RATIO 255
 
 /* Audio buffer size has to be a power of two to allow DMA buffer
-   fragments under the VoxWare (Linux & FreeBSD) audio driver */
+   fragments under the VoxWare (Linux & FreeBSD & BSD/OS) audio driver */
 #define AUDIO_BUFFER_SIZE (1<<AUDIO_BUFFER_BITS)
 #define BB_SIZE (AUDIO_BUFFER_SIZE*512)
 
@@ -269,7 +270,7 @@ typedef double FLOAT_T;
 # endif        
 #endif /* linux */
 
-#if defined(__FreeBSD__) || defined(__NetBSD__)
+#if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__bsdi__)
 #include <sys/types.h>
 #include <errno.h>
 #include <machine/endian.h>
@@ -455,7 +456,7 @@ extern char *sys_errlist[];
   #define PI 3.14159265358979323846
 #endif
 
-#ifdef __FreeBSD__
+#if defined (__FreeBSD__) || defined(__bsdi__) 
 #include <math.h>
 #ifndef PI
 #define PI M_PI
