@@ -3,7 +3,7 @@
  *
  *    kmidi
  *
- * $Id: configdlg.cpp,v 1.18 2000/08/27 22:06:30 greglee Exp $
+ * $Id: configdlg.cpp,v 1.19 2000/12/01 21:59:02 malte Exp $
  *
  * Copyright (C) 1997 Bernd Johannes Wuebben
  * wuebben@math.cornell.edu
@@ -46,12 +46,10 @@
 #include "configdlg.h"
 #include "kmidi.h"
 #include "version.h"
+#include "midiapplication.h"
 
 //QFont default_font("Helvetica", 12);
 
-extern KApplication *thisapp;
-extern KMidi *kmidi;
-
 extern const char * whatsthis_image[];
 
 ConfigDlg::ConfigDlg(QWidget *parent, struct configstruct *data, const char *name)
