@@ -5,7 +5,7 @@
  *   they refer to.  The routine load_fff_patch is adapted from "load_instrument",
  *   which is Copyright (C) 1995 Tuukka Toivonen <toivonen@clinet.fi>.
  *		-- Greg Lee, lee@Hawaii.edu, June, 1997.
- * $Id: fffload.cpp,v 1.1 1999/12/09 04:34:26 greglee Exp $
+ * $Id: fffload.cpp,v 1.2 2001/01/19 09:17:50 coolo Exp $
  */
 
 #include <stdio.h>
@@ -17,7 +17,7 @@
 #include <sys/stat.h>
 #include <strings.h>
 
-#ifdef __FreeBSD__
+#if defined (__FreeBSD__) || defined(__bsdi__)
 #include <stdlib.h>
 #else
 #include <malloc.h>
