@@ -1,5 +1,5 @@
 /*
-	$Id: instrum.cpp,v 1.9 2000/08/19 01:45:50 greglee Exp $
+	$Id: instrum.cpp,v 1.10 2001/01/19 09:17:50 coolo Exp $
 
     TiMidity -- Experimental MIDI to WAVE converter
     Copyright (C) 1995 Tuukka Toivonen <toivonen@clinet.fi>
@@ -32,7 +32,7 @@
 #include <strings.h>
 #endif
 
-#if defined(__FreeBSD__) || defined (__WIN32__)
+#if defined(__FreeBSD__) || defined (__WIN32__) || defined(__bsdi__)
 #include <stdlib.h>
 #else
 #include <malloc.h>
