@@ -2,7 +2,7 @@
 
    kmidi - a midi to wav converter
 
-   $Id: kmidi.cpp,v 1.111 2000/09/07 22:15:27 greglee Exp $
+   $Id: kmidi.cpp,v 1.112 2000/12/01 21:59:02 malte Exp $
 
    Copyright 1997, 1998 Bernd Johannes Wuebben math.cornell.edu
 
@@ -116,8 +116,6 @@ extern int fixframesizecount;
 //QFont default_font("Helvetica", 10, QFont::Bold);
 
 
-extern MidiApplication * thisapp;
-extern KMidiFrame *kmidiframe;
 KMidi *kmidi;
 Table		*channelwindow;
 
