@@ -1,7 +1,7 @@
 /*
  *        kmidi - midi to wav player/converter
  *
- * $Id: log.h,v 1.2 1998/06/10 01:52:34 wuebben Exp $
+ * $Id: log.h,v 1.7 2000/08/02 20:21:15 bieker Exp $
  *            Copyright (C) 1997  Bernd Wuebben
  *                 wuebben@math.cornel.edu 
  * 
@@ -25,32 +25,14 @@
 
 #include<stdlib.h>
 
-#include<qdialog.h>
-#include<qfont.h>
 #include<qstring.h>
-#include<qpainter.h>
-#include<qpixmap.h>
-#include<qlabel.h>
-#include<qmlined.h>
-#include<qpushbt.h>
+//#include<qpixmap.h>
+#include<qmultilinedit.h>
 #include <qtimer.h>
 #include <qstrlist.h>
 
 
-class myMultiEdit : public QMultiLineEdit {
-
-public:
-
-  myMultiEdit(QWidget *parent=0, const char *name=0);
-  ~myMultiEdit();
-
-bool rowYPos(int row, int& yPos);
-void newLine();
-void  insertChar(char c);
-};
-
-
-class LogWindow : public QDialog {
+class LogWindow : public QWidget {
 
 Q_OBJECT
 
@@ -58,47 +40,22 @@ public:
   LogWindow(QWidget *parent=0, const char *name=0);
   ~LogWindow();
 
-  void insertchar(char);
-  void insertStr(char*);
-  void statusLabel(const char *);
+  void insertStr(const QString &);
   void clear();
 
 private slots:
-    void hideit();
-    void updatewindow();
+  void updatewindow();
 
 private:
-      void resizeEvent(QResizeEvent *e);
+  void resizeEvent(QResizeEvent *e);
 
 private:
 
   bool timerset;
   QTimer *sltimer;
-  QStrList *stringlist;
-  void enter();
-  QFrame *fline;
-  QPushButton *dismiss;
-  myMultiEdit *text_window;
-
-  QLabel *statuslabel;
+  QStringList *stringlist;
+  QMultiLineEdit *text_window;
 
 };
 #endif
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
