@@ -1,5 +1,5 @@
 /*
-	$Id: resample_f.cpp,v 1.2 1999/12/26 21:35:59 greglee Exp $
+	$Id: resample_f.cpp,v 1.3 2001/01/19 09:17:50 coolo Exp $
 
     TiMidity++ -- MIDI to WAVE converter and player
     Copyright (C) 1999 Masanao Izumo <mo@goice.co.jp>
@@ -23,7 +23,7 @@
 
 #include <math.h>
 #include <stdio.h>
-#ifdef __FreeBSD__
+#if defined(__FreeBSD__) || defined(__bsdi__)
 #include <stdlib.h>
 #else
 #include <malloc.h>
