@@ -39,6 +39,7 @@
 #include <kmessagebox.h>
 #include <kaction.h>
 #include <kpopupmenu.h>
+#include <kiconloader.h>
 
 #include "kmixerwidget.h"
 #include "mixer.h"
@@ -177,6 +178,14 @@ void KMixerWidget::setIcons( bool on )
    }
 }
 
+void KMixerWidget::setColors( const Colors &color )
+{
+    for ( Channel *chn=m_channels.first(); chn!=0; chn=m_channels.next() ) {
+        chn->dev->setColors( color.high, color.low, color.back );
+        chn->dev->setMutedColors( color.mutedHigh, color.mutedLow, color.mutedBack );
+    }
+}
+
 void KMixerWidget::mousePressEvent( QMouseEvent *e )
 {
    if ( e->button()==RightButton )
@@ -185,7 +194,8 @@ void KMixerWidget::mousePressEvent( QMouseEvent *e )
 
 void KMixerWidget::rightMouseClicked()
 {
-   KPopupMenu *menu = new KPopupMenu( i18n("Device settings"), this );
+   KPopupMenu *menu = new KPopupMenu( this );
+   menu->insertTitle( SmallIcon( "kmix" ), i18n("Device settings") );
 
    KAction *a = m_actions->action( "show_all" );
    if ( a ) a->plug( menu );
