@@ -34,7 +34,6 @@
 #include <qlayout.h>
 #include <qpixmap.h>
 #include <qtooltip.h>
-#include <qpopupmenu.h>
 #include <qtimer.h>
 #include <qwmatrix.h>
 
@@ -288,7 +287,8 @@ void MixDeviceWidget::setStereoLinked(bool value)
 {
    m_linked = value;
 
-   for( QWidget *slider=m_sliders.at( 1 ); slider!=0 ; slider=m_sliders.next() )
+   QWidget *slider = m_sliders.first();
+   for( slider=m_sliders.next(); slider!=0 ; slider=m_sliders.next() )
       value ? slider->hide() : slider->show();
 
    layout()->activate();
@@ -341,6 +341,22 @@ void MixDeviceWidget::setIcons(bool value)
    }
 }
 
+void MixDeviceWidget::setColors( QColor high, QColor low, QColor back )
+{
+    for( QWidget *slider=m_sliders.first(); slider!=0; slider=m_sliders.next() ) {
+        KSmallSlider *smallSlider = dynamic_cast<KSmallSlider*>(slider);
+        if ( smallSlider ) smallSlider->setColors( high, low, back );
+    }
+}
+
+void MixDeviceWidget::setMutedColors( QColor high, QColor low, QColor back )
+{
+    for( QWidget *slider=m_sliders.first(); slider!=0; slider=m_sliders.next() ) {
+        KSmallSlider *smallSlider = dynamic_cast<KSmallSlider*>(slider);
+        if ( smallSlider ) smallSlider->setGrayColors( high, low, back );
+    }
+}
+
 void MixDeviceWidget::volumeChange( int )
 {
    Volume vol = m_mixdevice->getVolume();
@@ -470,7 +486,8 @@ void MixDeviceWidget::update()
 
 void MixDeviceWidget::contextMenu()
 {
-   KPopupMenu *menu = new KPopupMenu( i18n("Device settings"), this );
+   KPopupMenu *menu = new KPopupMenu( this );
+   menu->insertTitle( SmallIcon( "kmix" ), i18n("Device settings") );
 
    if ( m_sliders.count()>1 )
    {
