@@ -6,7 +6,7 @@
  *      --- This file has been manually midified ---
  *
  *
- * $Id: CDDialog.cpp,v 1.41 2000/09/30 05:09:28 dfoerste Exp $
+ * $Id: CDDialog.cpp,v 1.43 2000/12/16 17:40:08 yoush Exp $
  *
  ***********************************************************************/
 
@@ -24,6 +24,7 @@
 
 #include <klocale.h>
 #include <kdebug.h>
+#include <ktempfile.h>
 
 #include <stdio.h>
 #include <math.h>
@@ -226,18 +227,18 @@ CDDialog::setData(
 
     QString idstr;
     idstr.sprintf("%08lx",cddb_discid());
-    idstr = category + '\n' + idstr;
+    idstr = category + "  " + idstr;
 
-    disc_id_label->setText(idstr);
+    disc_id_label->setText(idstr.stripWhiteSpace());
 
     QTime   dl;
     dl 	=  dl.addSecs(cdinfo.length);
 
     QString temp2;
     if(dl.hour() > 0)
-      temp2 = QString::fromUtf8( QCString().sprintf(i18n("Total Time:\n %02d:%02d:%02d").utf8(),dl.hour(),dl.minute(),dl.second()) );
+      temp2 = QString::fromUtf8( QCString().sprintf("%02d:%02d:%02d",dl.hour(),dl.minute(),dl.second()) );
     else
-      temp2 = QString::fromUtf8( QCString().sprintf(i18n("Total Time:\n %02d:%02d").utf8(),dl.minute(),dl.second()) );
+      temp2 = QString::fromUtf8( QCString().sprintf("%02d:%02d",dl.minute(),dl.second()) );
     total_time_label->setText(temp2);
 
     QString 	fmt;
@@ -427,8 +428,9 @@ CDDialog::upload()
   dialog->getSelection(submitcat);
   delete dialog;
 
-  QString tempfile;
-  tempfile = tmpnam(0L);
+  KTempFile tmpFile;
+  tmpFile.setAutoDelete(true); // delete file when we are done.
+  QString tempfile = tmpFile.name();
 
   save_cddb_entry(tempfile,true);
 
@@ -515,7 +517,6 @@ CDDialog::upload()
   file.close();
   //  file2.close();   // *****
 
-  unlink(QFile::encodeName(tempfile));
   kdDebug() << "DONE SENDING\n" << endl;
 } // upload
 
