@@ -1,10 +1,10 @@
 
 
-/*   
+/*
    Kscd - A simple cd player for the KDE Project
 
-   $Id: inexact.cpp,v 1.12 2000/08/09 17:51:25 bieker Exp $
- 
+   $Id: inexact.cpp,v 1.14 2000/12/27 22:17:27 tibirna Exp $
+
    Copyright (c) 1997 Bernd Johannes Wuebben math.cornell.edu
 
    This program is free software; you can redistribute it and/or modify
@@ -32,89 +32,90 @@
 
 #include "inexact.h"
 
+#include <qlayout.h>
+
+
 InexactDialog::InexactDialog(QWidget *parent, const char *name,bool _listbox)
   : QDialog(parent, name, TRUE)
 {
 
   setCaption("Kscd");
-  
+
+  QBoxLayout * lay1 = new QVBoxLayout ( this, 10 );
+  text = new QLabel(this,"textlabel");
+//  text->setAlignment(WordBreak|AlignCenter);
+  lay1->addWidget ( text );
+
   listbox = _listbox;
   if(listbox)
     {
       list_box = new QListBox(this,"debugwindow");
-      list_box->setGeometry(2,5,400, 300);
+      list_box->setColumnMode(QListBox::FitToWidth);
+      lay1->addWidget ( list_box );
       connect(list_box,SIGNAL(highlighted(int)),SLOT(setStatusBar(int)));
     } else {
       edit = new QMultiLineEdit(this,"debugwindow");
-      edit->setGeometry(2,5,400, 300);
-    }
-  
-  
-  text = new QLabel(this,"textlabel");
-  text->setAlignment(WordBreak|AlignCenter);
-  
+      lay1->addWidget ( edit );
+   }
+
+
+
   text->setText(i18n("No exact match could be found. Please select the appropriate"\
-		     " CD from the list of choices presented below."));
-  
+                     " CD from the list of choices presented below."));
+
   errorstring = i18n("Please select a Disk Title or press Cancel");
-  
+
   statuslabel = new QLabel( this, "statuslabel" );
-  
+  lay1->addWidget ( statuslabel );
   statuslabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
   statuslabel->setText( "" );
   statuslabel->setAlignment( AlignCenter );
-  statuslabel->setGeometry(2, 307, 400, 20);
   //statusPageLabel->setFont( QFont("helvetica",12,QFont::Normal) );
-  
-  cancel_button = new QPushButton(this,"cancel_button");
-  cancel_button->setGeometry(330,340,70,30);
-  cancel_button->setText(i18n("Cancel"));
+
+  QBoxLayout * lay2 = new QHBoxLayout ( lay1 );
+  lay2->addStretch ( 1 );
+  ok_button = new QPushButton(i18n("OK"),this,"ok_button");
+  lay2->addWidget ( ok_button );
+  lay2->addStretch ( 1 );
+  cancel_button = new QPushButton(i18n("Cancel"),this,"cancel_button");
+  lay2->addWidget ( cancel_button );
+  lay2->addStretch ( 1 );
   cancel_button->setFocus();
 
-  ok_button = new QPushButton(this,"ok_button");
-  ok_button->setGeometry(250,340,70,30);
-  ok_button->setText(i18n("OK"));
-  //  ok_button->setFocus();
-
-
   connect(ok_button,SIGNAL(clicked()),SLOT(checkit()));
   connect(cancel_button,SIGNAL(clicked()),SLOT(reject()));
 
   returnstring = "";
-
-  adjustSize();
-  setMinimumSize(width(),height());
-  
 } // InexactDialog()
 
 
-InexactDialog::~InexactDialog() 
+InexactDialog::~InexactDialog()
 {
 }
 
-void 
+void
 InexactDialog::setTitle(const QString& t)
 {
   titlestring = t;
   text->setText(t);
 }
 
-void 
+void
 InexactDialog::setErrorString(const QString& t)
 {
   errorstring = t;
 }
 
-void 
+void
 InexactDialog::checkit()
 {
   if(listbox)
     {
       if(list_box->currentItem() == -1)
-	{
-	  KMessageBox::information(this, errorstring);
-	  return;
-	}
+        {
+          KMessageBox::information(this, errorstring);
+          return;
+        }
       returnstring = list_box->text(list_box->currentItem());
     } else {
       returnstring = edit->text();
@@ -122,14 +123,14 @@ InexactDialog::checkit()
   accept();
 }
 
-void 
+void
 InexactDialog::getSelection(QString& string)
 {
   string = returnstring;
 }
 
 
-void 
+void
 InexactDialog::insertList(const QStringList& stringlist)
 {
   if(listbox)
@@ -138,7 +139,7 @@ InexactDialog::insertList(const QStringList& stringlist)
     }
 }
 
-void 
+void
 InexactDialog::insertText(const QString& str)
 {
   if(!listbox)
@@ -149,29 +150,11 @@ InexactDialog::insertText(const QString& str)
     }
 }
 
-void 
+void
 InexactDialog::setStatusBar(int i)
 {
   returnstring = list_box->text(i);
   statuslabel->setText(returnstring);
 }
 
-void 
-InexactDialog::resizeEvent(QResizeEvent *)
-{
-  
-  int w = width() ;
-  int h = height();
-  text->setGeometry(10,5,w-10,45);
-  if(listbox)
-    {
-      list_box->setGeometry(2,45 + 5,w - 2 ,h - 60 -45 );
-    } else {
-      edit->setGeometry(2,45 + 5,w - 2 ,h - 60 -45 );
-    }
-  statuslabel->setGeometry(2, h - 53 , w -2 , 20);
-  ok_button->setGeometry(w - 72 - 80 , h - 28, 70, 25);
-  cancel_button->setGeometry(w - 72 , h - 28, 70, 25);
-}
-
 #include "inexact.moc"
