@@ -1,5 +1,5 @@
 /*
- * $Id: cdrom.c,v 1.3 2000/06/02 13:50:11 hoelzer Exp $
+ * $Id: cdrom.c,v 1.6 2001/02/04 10:42:35 dfoerste Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -27,7 +27,7 @@
  * platform- or drive-dependent code here.
  */
 
-static char cdrom_id[] = "$Id: cdrom.c,v 1.3 2000/06/02 13:50:11 hoelzer Exp $";
+static char cdrom_id[] = "$Id: cdrom.c,v 1.6 2001/02/04 10:42:35 dfoerste Exp $";
 
 #include <errno.h>
 #include <stdio.h>
@@ -539,9 +539,11 @@ wm_cd_pause( void )
 	case WM_CDM_PAUSED:		/* paused */
 		cur_cdmode = WM_CDM_PLAYING;
 /*		(drive.resume)(&drive); */
-		if ((drive.resume)(&drive))
+		if ((drive.resume)(&drive) > 0 )
+                  {
 			wm_cd_play(cur_track, paused_pos,
 				playlist[cur_listno-1].end);
+                  }
 	default: /* */
 		break;	
 	}
@@ -597,15 +599,45 @@ wm_cd_play( int start, int pos, int end )
 	if (cur_cdmode == WM_CDM_EJECTED || cd == NULL)
 		return;
 
+        /*
+         * Try to avoid mixed mode and CD-EXTRA data tracks
+         */
+        if( (start == 1) && (cd->trk[start-1].data == 1))
+          {
+            start++;
+          }
+
+        /* -2: -1 (array-index) + -1 (leadout->last track)*/
+        if( (cd->trk[end-2].data == 1 ) )
+          {
+            end--;
+          }
+
+        /* CD-EXTRA: The data track was requested to play.
+         * Play the last audio track instead.
+         */
+        if( start >= end )
+          {
+            start = end-1;
+          }
+
 	cur_firsttrack = start;
 	start--;
 	end--;
 	cur_lasttrack = end;
 
-	wm_cd_play_chunk(cd->trk[start].start + pos * 75, end >= cur_ntracks ?
-		cur_cdlen * 75 : cd->trk[end].start - 1,
-		cd->trk[start].start);
+        /* Don't play if it's just one data track or still a data track */
+        if( start < 0 ) start = 0;
+        if( cd->trk[start].data == 1 )
+          {
+            wm_cd_status();
+            cur_cdmode = WM_CDM_STOPPED;
+            return;
+          }
 
+        wm_cd_play_chunk(cd->trk[start].start + pos * 75, end >= cur_ntracks ?
+                         cur_cdlen * 75 : cd->trk[end].start - 1,
+                         cd->trk[start].start);
 	/* So we don't update the display with the old frame number */
 	wm_cd_status();
 	cur_frame = cd->trk[start].start + pos * 75;
