@@ -1,7 +1,7 @@
 #ifndef WM_CONFIG_H
 #define WM_CONFIG_H
 /*
- * $Id: wm_config.h,v 1.6.2.1 2000/11/07 05:46:04 dfoerste Exp $
+ * $Id: wm_config.h,v 1.8 2001/01/19 09:17:50 coolo Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -115,6 +115,8 @@
  */
 #define SOUNDBLASTER 1
 
+#define DEFAULT_CD_DEVICE "/dev/rsr2c" 
+
 #endif /* __bsdi__ (BSD/386) */
 
 /******************************************************************
@@ -197,7 +199,7 @@
  * Linux Soundcard support
  * Disabled by default, because some people rely on it
  */
-/*#define OSS_SUPPORT 1 */
+/* #define OSS_SUPPORT 1 */
 
 /*
  * This has nothing to do with the above.
@@ -211,9 +213,8 @@
  * drives as well. But it may be possible, that it doesn't work at all.
  * If your drive/driver combination cannot handle the faster access,
  * the driver will usually hang and you have to reboot your machine.
- * [Defaulted this to be enabled, because KSCD-1.2.7 did it anyway.]
  */
-#define FAST_IDE 1
+/* #define FAST_IDE 1 */
 
 /*
  * There are two alternative ways of checking a device containing a
