@@ -1,5 +1,5 @@
 /*
- * $Id: plat_freebsd.c,v 1.4.2.1 2000/11/24 06:08:23 kevlo Exp $
+ * $Id: plat_freebsd.c,v 1.7 2001/01/30 05:56:20 dfoerste Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -30,7 +30,7 @@
  *
  */
 
-static char freebsd_id[] = "$Id: plat_freebsd.c,v 1.4.2.1 2000/11/24 06:08:23 kevlo Exp $";
+static char freebsd_id[] = "$Id: plat_freebsd.c,v 1.7 2001/01/30 05:56:20 dfoerste Exp $";
 
 #if defined(__FreeBSD__) || defined(__FreeBSD) || defined(__NetBSD__) || defined (__NetBSD)
 
@@ -50,10 +50,11 @@ static char freebsd_id[] = "$Id: plat_freebsd.c,v 1.4.2.1 2000/11/24 06:08:23 ke
 #include <sys/ioctl.h>
 #include <sys/cdio.h>
 
-#if defined(__NetBSD__)
+#if defined(__NetBSD__) || defined(__OpenBSD__) 
 # define MSF_MINUTES 1
 # define MSF_SECONDS 2
 # define MSF_FRAMES 3
+#include <sys/scsiio.h>
 # include "/sys/scsi/scsi_all.h"
 # include "/sys/scsi/scsi_cd.h"
 #else
@@ -116,25 +117,13 @@ wmcd_open( struct wm_drive *d )
     {
       if (errno == EACCES)
 	{
-	  if (!warned)
-	    {
-	      fprintf(stderr,
-		      "As root, please run\n\nchmod 666 %s\n\n%s\n", cd_device,
-		      "to give yourself permission to access the CD-ROM device.");
-	      warned++;
-	    }
+          return -EACCES;
 	}
       
       /* No CD in drive. */
       return (1);
     }
-  
-  if (warned)
-    {
-      warned = 0;
-      fprintf(stderr, "Thank you.\n");
-    }
-  
+    
   /* Now fill in the relevant parts of the wm_drive structure. */
   fd = d->fd;
   
