@@ -1,5 +1,5 @@
 /*
- * $Id: plat_linux.c,v 1.8 2000/08/30 04:40:36 dfoerste Exp $
+ * $Id: plat_linux.c,v 1.11 2001/02/04 09:57:33 dfoerste Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -25,7 +25,7 @@
  * Linux-specific drive control routines.  Very similar to the Sun module.
  */
 
-static char plat_linux_id[] = "$Id: plat_linux.c,v 1.8 2000/08/30 04:40:36 dfoerste Exp $";
+static char plat_linux_id[] = "$Id: plat_linux.c,v 1.11 2001/02/04 09:57:33 dfoerste Exp $";
 
 #if defined(__linux__)
 
@@ -135,13 +135,7 @@ wmcd_open( struct wm_drive *d )
     {
       if (errno == EACCES)
 	{
-	  if (!warned)
-	    {
-	      fprintf(stderr,
-		      "As root, please run\n\nchmod 666 %s\n\n%s\n", cd_device,
-		      "to give yourself permission to access the CD-ROM device.");
-	      warned++;
-	    }
+          return -EACCES;
 	}
       /* Hack proposed by Carey Evans, introduced by Debian maintainer :
        * treat EIO like ENXIO since some Linux drives do never return ENXIO
@@ -149,20 +143,13 @@ wmcd_open( struct wm_drive *d )
        */
       else if ((errno != ENXIO) && (errno != EIO) && (errno != ENOMEDIUM))
 	{
-	  perror(cd_device);
-	  exit(1);
+          return (-6);
 	}
       
       /* No CD in drive. */
       retval = 1;
     }
   
-  if (warned)
-    {
-      warned = 0;
-      fprintf(stderr, "Thank you.\n");
-    }
-  
   /* Now fill in the relevant parts of the wm_drive structure. */
   fd = d->fd;
   
@@ -423,8 +410,8 @@ int
 gen_get_cdlen(struct wm_drive *d, int *frames)
 {
   int		tmp;
-  
-  return (gen_get_trackinfo(d, CDROM_LEADOUT, &tmp, frames));
+
+  return gen_get_trackinfo( d, CDROM_LEADOUT, &tmp, frames);
 } /* gen_get_cdlen() */
 
 
@@ -435,7 +422,7 @@ int
 gen_play(struct wm_drive *d, int start, int end)
 {
   struct cdrom_msf		msf;
-  
+
   msf.cdmsf_min0 = start / (60*75);
   msf.cdmsf_sec0 = (start % (60*75)) / 75;
   msf.cdmsf_frame0 = start % 75;
@@ -443,13 +430,26 @@ gen_play(struct wm_drive *d, int start, int end)
   msf.cdmsf_sec1 = (end % (60*75)) / 75;
   msf.cdmsf_frame1 = end % 75;
   
-#ifndef FAST_IDE
-  if (ioctl(d->fd, CDROMSTART))
-    return (-1);
-#endif		
   if (ioctl(d->fd, CDROMPLAYMSF, &msf))
-    return (-2);
+    {
+      if (ioctl(d->fd, CDROMSTART))
+        return (-1);
+      if (ioctl(d->fd, CDROMPLAYMSF, &msf))
+        return (-2);
+    }
   
+  /*
+   * I hope no drive gets really confused after CDROMSTART
+   * If so, I need to make this run-time configurable.
+   * 
+#ifndef FAST_IDE
+  if (ioctl( d->fd, CDROMSTART))
+      return (-1);
+#endif
+  if (ioctl( d->fd, CDROMPLAYMSF, &msf ))
+      return (-2);
+    */  
+
   return (0);
 } /* gen_play() */
 
