@@ -1,5 +1,5 @@
 /*
- * $Id: plat_sun.c,v 1.8 2000/10/17 22:14:40 coolo Exp $
+ * $Id: plat_sun.c,v 1.10 2001/01/30 05:56:20 dfoerste Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -25,7 +25,7 @@
  * Sun-specific drive control routines.
  */
 
-static char plat_sun_id[] = "$Id: plat_sun.c,v 1.8 2000/10/17 22:14:40 coolo Exp $";
+static char plat_sun_id[] = "$Id: plat_sun.c,v 1.10 2001/01/30 05:56:20 dfoerste Exp $";
 
 #if defined(sun) || defined(__sun)
 
@@ -213,36 +213,27 @@ wmcd_open( struct wm_drive *d )
 	{
 	  if (!warned)
 	    {
+              /*
 	      char	realname[MAXPATHLEN];
 	      
 	      if (realpath(cd_device, realname) == NULL)
 		{
 		  perror("realpath");
-		  return (-1);
+		  return (1);
 		}
-	      
-	      fprintf(stderr,
-		      "As root, please run\n\nchmod 666 %s\n\n%s\n", realname,
-		      "to give yourself permission to access the CD-ROM device.");
-	      warned++;
-	    }
+                */
+              return -EACCES;
+            }
 	}
       else if (errno != ENXIO)
 	{
-	  perror(cd_device);
-	  exit(1);
+          return( -6 );
 	}
       
       /* No CD in drive. */
       return (1);
     }
   
-  if (warned)
-    {
-      warned = 0;
-      fprintf(stderr, "Thank you.\n");
-    }
-  
   /* Now fill in the relevant parts of the wm_drive structure. */
   fd = d->fd;
   
