@@ -7,7 +7,7 @@
  */
 
 #include "../../lib/mpgplayer/mpgPlugin.h"
-
+#include "../../lib/util/timeWrapper.h"
 
 int main(int argc, char** argv) {
 
@@ -28,8 +28,8 @@ int main(int argc, char** argv) {
   // in fact you can, but this gives you a segfault!
     
   MpgPlugin* plugin=new MpgPlugin();
-  OutputStream* out=OutPlugin::createOutputStream(_OUTPUT_LOCAL);
-  InputStream* in=InputPlugin::createInputStream(argv[1]);
+  OutputStream* out=OutPlugin::createOutputStream(_OUTPUT_LOCAL,true);
+  InputStream* in=InputPlugin::createInputStream(argv[1],true);
 
 
 
@@ -54,7 +54,7 @@ int main(int argc, char** argv) {
   while(1) {
     if (plugin->getStreamState() != _STREAM_STATE_EOF) {
       cout << "******* plugin->getStreamState() continue"<<endl;
-      sleep(3);
+      TimeWrapper::sleep(3);
       continue;
     }
     break;
