@@ -8,6 +8,7 @@
 
 #include "../../lib/splay/splayPlugin.h"
 #include "../../lib/tplay/tplayPlugin.h"
+#include "../../lib/decoder/vorbisPlugin.h"
 #include "../../lib/input/bufferInputStream.h"
 #include "../../lib/output/avSyncer.h"
 
@@ -30,12 +31,12 @@ int main(int argc, char** argv) {
   // 
   // you cannot set the input _before_ the output 
   // in fact you can, but this gives you a segfault!
-
-  SplayPlugin* plugin=new SplayPlugin();
+  while(1) {
+  DecoderPlugin* plugin=new VorbisPlugin();
   //TplayPlugin* plugin=new TplayPlugin();
-  OutputStream* out=OutPlugin::createOutputStream(_OUTPUT_LOCAL);
+  OutputStream* out=OutPlugin::createOutputStream(_OUTPUT_LOCAL,true);
 
-  InputStream* in=InputPlugin::createInputStream(argv[1]);
+  InputStream* in=InputPlugin::createInputStream(argv[1],true);
 
 
   // The plugin does not do "open"
@@ -47,21 +48,22 @@ int main(int argc, char** argv) {
 
   plugin->play();
 
-
+  /*
   while(plugin->getStreamState() != _STREAM_STATE_EOF) {
     cout << "check state"<<endl;
     sleep(1);
 
   }
-
+  */
+  sleep(4);
   cout << "****************plugin eof"<<endl;
-  out->audioClose();
+  //out->audioClose();
   plugin->close();
 
   delete plugin;
   delete in;
   delete out;
-
+  }
   
 }
   
