@@ -10,6 +10,7 @@
 
 
 #include "../../lib/tplay/tplayPlugin.h"
+#include "../../lib/decoder/nukePlugin.h"
 
 #include "../../lib/util/audio/audioWrapper.h"
 
@@ -33,9 +34,10 @@ int main(int argc, char** argv) {
   // you cannot set the input _before_ the output 
   // in fact you can, but this gives you a segfault!
     
-  TplayPlugin* plugin=new TplayPlugin();
-  OutputStream* out=OutPlugin::createOutputStream(_OUTPUT_LOCAL);
-  InputStream* in=InputPlugin::createInputStream(argv[1]);
+  DecoderPlugin* plugin=new TplayPlugin();
+  //DecoderPlugin* plugin=new NukePlugin();
+  OutputStream* out=OutPlugin::createOutputStream(_OUTPUT_LOCAL,true);
+  InputStream* in=InputPlugin::createInputStream(argv[1],true);
 
   // The plugin does not do "open"
   in->open(argv[1]);
