@@ -18,13 +18,8 @@
 
 extern "C" {
 #include <stdio.h>
-#include <sys/types.h>
-#include <sys/ioctl.h>
 #include <stdlib.h>
-#include <sys/stat.h>
-#include <fcntl.h>
 #include <string.h>
-#include <unistd.h>
 }
 
 struct TocEntry {
@@ -58,9 +53,9 @@ class CDRomToc {
 
  private:
   // platform specific calls.
-  int getStartEnd(int fd,int& start, int& end);
-  int readToc(int fd,int num,int& min,int& sec, int& frame);
-  int readLeadOut(int fd,int& min,int& sec, int& frame);
+  int getStartEnd(FILE* file,int& start, int& end);
+  int readToc(FILE* file,int num,int& min,int& sec, int& frame);
+  int readLeadOut(FILE* file,int& min,int& sec, int& frame);
 
 
 
