@@ -170,7 +170,7 @@ int DecoderClass::decodeDCTDCSizeChrom() {
  *      mb_addr_inc.
  *
  * Results:
- *      The decoded value for macro_block_address_increment or ERROR
+ *      The decoded value for macro_block_address_increment or MPGDECODE_ERROR
  *      for unbound values will be placed in the location specified.
  *
  * Side effects:
@@ -211,7 +211,7 @@ int DecoderClass::decodeMBAddrInc() {
  *      lookup on motion_vectors.
  *
  * Results:
- *      The decoded value for the motion vector or ERROR for unbound
+ *      The decoded value for the motion vector or MPGDECODE_ERROR for unbound
  *      values will be placed in the location specified.
  *
  * Side effects:
@@ -241,7 +241,7 @@ int DecoderClass::decodeMotionVectors() {
  *      coded_block_pattern.
  *
  * Results:
- *      The decoded value for coded_block_pattern or ERROR for unbound
+ *      The decoded value for coded_block_pattern or MPGDECODE_ERROR for unbound
  *      values will be placed in the location specified.
  *
  * Side effects:
@@ -278,7 +278,7 @@ int DecoderClass::decodeCBP() {
  *
  * Results:
  *      The various decoded values for macro_block_type in
- *      bidirectionally-coded pictures or ERROR for unbound values will
+ *      bidirectionally-coded pictures or MPGDECODE_ERROR for unbound values will
  *      be placed in the locations specified.
  *
  * Side effects:
@@ -317,7 +317,7 @@ void DecoderClass::decodeMBTypeB(int& quant,int& motion_fwd,
  *
  * Results:
  *      The various decoded values for macro_block_type in intra-coded
- *      pictures or ERROR for unbound values will be placed in the
+ *      pictures or MPGDECODE_ERROR for unbound values will be placed in the
  *      locations specified.
  *
  * Side effects:
@@ -329,7 +329,7 @@ void DecoderClass::decodeMBTypeI(int& quant,int& motion_fwd,
 				 int& motion_bwd,int& pat,int& intra) {
 
   unsigned int index;							
-  static int quantTbl[4] = {ERROR, 1, 0, 0};				
+  static int quantTbl[4] = {MPGDECODE_ERROR, 1, 0, 0};				
 									
   index=mpegVideoStream->showBits(2);
 									
@@ -338,7 +338,7 @@ void DecoderClass::decodeMBTypeI(int& quant,int& motion_fwd,
   pat = 0;								
   intra = 1;								
   quant = quantTbl[index];						
-  if (quant == ERROR) {
+  if (quant == MPGDECODE_ERROR) {
     cout << "decodeMBTypeI Error"<<endl;
   }
   if (index) {								
@@ -363,7 +363,7 @@ void DecoderClass::decodeMBTypeI(int& quant,int& motion_fwd,
  * 
  * Results:
  *      The various decoded values for macro_block_type in
- *      predictive-coded pictures or ERROR for unbound values will be
+ *      predictive-coded pictures or MPGDECODE_ERROR for unbound values will be
  *      placed in the locations specified.
  *
  * Side effects:
@@ -431,7 +431,8 @@ void DecoderClass::decodeMBTypeP(int& quant,int& motion_fwd,
  *      
  *
  * Results:
- *      The decoded values of run and level or ERROR for unbound values
+ *      The decoded values of run and level or MPGDECODE_ERROR 
+ *      for unbound values
  *      are placed in the locations specified.
  *
  * Side effects:
