@@ -58,4 +58,12 @@ OutputStream* OutPlugin::createOutputStream(int outputType) {
 
 }
 
-  
+OutputStream* OutPlugin::createOutputStream(int outputType,int lThreadSafe) {
+  OutputStream* output=OutPlugin::createOutputStream(outputType);
+  if (lThreadSafe==false) {
+    return output;
+  }
+  OutputStream* tsOutput=new ThreadSafeOutputStream(output);
+  return tsOutput;
+}
+ 
