@@ -70,24 +70,3 @@ void MpegAudioBitWindow::wrap(void) {
   }
   *((int *)(buffer+WINDOWSIZE))=*((int *)buffer);
 }
-
-int MpegAudioBitWindow::getbit(void) {
-  register int r=(buffer[(bitindex>>3)&(WINDOWSIZE-1)]>>(7-(bitindex&7)))&1;
-  //register int r=(buffer[bitindex>>3]>>(7-(bitindex&7)))&1;
-  bitindex++;
-  return r;
-};
-
-
-int MpegAudioBitWindow::getbits9(int bits) {
-  register unsigned short a;
-  {
-    int offset=(bitindex>>3)&(WINDOWSIZE-1);
-    //int offset=bitindex>>3;
-    a=(((unsigned char)buffer[offset])<<8) | ((unsigned char)buffer[offset+1]);
-  }
-
-  a<<=(bitindex&7);
-  bitindex+=bits;
-  return (int)((unsigned int)(a>>(16-bits)));
-}
