@@ -47,9 +47,33 @@ class MpegAudioBitWindow {
   void wrap(void);
   void rewind(int bits)  {bitindex-=bits;}
   void forward(int bits) {bitindex+=bits;}
-  int  getbit(void);
-  int  getbits9(int bits);
   int  getbits(int bits);
+
+  int getbit(void) {
+    register int r=(buffer[(bitindex>>3)&(WINDOWSIZE-1)]>>(7-(bitindex&7)))&1;
+    //register int r=(buffer[bitindex>>3]>>(7-(bitindex&7)))&1;
+    bitindex++;
+    return r;
+  }
+
+  int getbits9(int bits) {
+    register unsigned short a;
+    {
+      int offset=(bitindex>>3)&(WINDOWSIZE-1);
+      //int offset=bitindex>>3;
+      a=(((unsigned char)buffer[offset])<<8) | ((unsigned char)buffer[offset+1]);
+    }
+
+    a<<=(bitindex&7);
+    bitindex+=bits;
+    return (int)((unsigned int)(a>>(16-bits)));
+  }
+
+  int  peek8() {
+    int offset = (bitindex>>3)&(WINDOWSIZE-1), a;
+	a=(((unsigned char)buffer[offset])<<8) | ((unsigned char)buffer[offset+1]);
+    return (a >> (8-(bitindex&7))) & 0xff;
+  }  
   
 
 };
