@@ -14,6 +14,7 @@
  
 
 #include "mpegsound.h"
+#include "huffmanlookup.h"
 
 
 
@@ -54,7 +55,7 @@ __asm__ __volatile__(
 }
 #endif
 
-#define FOURTHIRDSTABLENUMBER (1<<13)
+#define FOURTHIRDSTABLENUMBER (8250)
 static int initializedlayer3=false;
 
 static REAL two_to_negative_half_pow[40];
@@ -81,137 +82,123 @@ static RATIOS rat_1[16],rat_2[2][64];
 void Mpegtoraw::layer3initialize(void)
 {
 
-  {
-   int i;
-
-   for(i=0;i<16;i++)hcos_64[i]=1.0/(2.0*cos(MY_PI*double(i*2+1)/64.0));
-   for(i=0;i< 8;i++)hcos_32[i]=1.0/(2.0*cos(MY_PI*double(i*2+1)/32.0));
-   for(i=0;i< 4;i++)hcos_16[i]=1.0/(2.0*cos(MY_PI*double(i*2+1)/16.0));
-   for(i=0;i< 2;i++)hcos_8 [i]=1.0/(2.0*cos(MY_PI*double(i*2+1)/ 8.0));
-   hcos_4=1.0/(2.0*cos(MY_PI*1.0/4.0));
-  }
-
-
+  int i,j,k,l;
 
+  
+  for(i=0;i<16;i++)hcos_64[i]=1.0/(2.0*cos(MY_PI*double(i*2+1)/64.0));
+  for(i=0;i< 8;i++)hcos_32[i]=1.0/(2.0*cos(MY_PI*double(i*2+1)/32.0));
+  for(i=0;i< 4;i++)hcos_16[i]=1.0/(2.0*cos(MY_PI*double(i*2+1)/16.0));
+  for(i=0;i< 2;i++)hcos_8 [i]=1.0/(2.0*cos(MY_PI*double(i*2+1)/ 8.0));
+  hcos_4=1.0/(2.0*cos(MY_PI*1.0/4.0));
 
   layer3framestart=0;
   currentprevblock=0;
 
-  {
-    int i,j,k,l;
-  
-    for(l=0;l<2;l++)
-      for(i=0;i<2;i++)
-	for(j=0;j<SBLIMIT;j++)
-	  for(k=0;k<SSLIMIT;k++)
-	    prevblck[l][i][j][k]=0.0f;
-  }
+  for(l=0;l<2;l++)
+    for(i=0;i<2;i++)
+      for(j=0;j<SBLIMIT;j++)
+	for(k=0;k<SSLIMIT;k++)
+	  prevblck[l][i][j][k]=0.0f;
 
   bitwindow.initialize();
 
   if(initializedlayer3)return;
 
   // Calculate win
-  {
-    int i;
 
-    for(i=0;i<18;i++) {
-      /*
+
+
+  for(i=0;i<18;i++) {
+    /*
       win[0][i]=win[1][i]=0.5*sin(PI_72*(double)(2*i+1))/
       cos(PI_72*(double)(2*i+19));
-      */
-      win[0][i]=win[1][i]=0.5*sin(PI_72*(double)(2*(i+0)+1))/cos(MY_PI * (double) (2*(i+0) +19) / 72.0 );
-      win[0][i+18] = win[3][i+18] = 0.5 * sin( MY_PI / 72.0 * (double) (2*(i+18)+1) ) / cos ( MY_PI * (double) (2*(i+18)+19) / 72.0 );
-    }
-    /*
-    for(;i<36;i++) {
-      win[0][i]=win[3][i]=0.5*sin(PI_72*(double)(2*i+1))/cos(PI_72*(double)(2*i+19));
-      
-    }
     */
-    for(i=0;i<6;i++)
-    {
-      win[1][i+18]=0.5/cos(MY_PI*(double)(2*(i+18)+19)/72.0);
-      win[3][i+12]=0.5/cos(MY_PI*(double)(2*(i+12)+19)/72.0);
-      win[1][i+24]=0.5*sin(PI_24*(double)(2*i+13))/cos(MY_PI*(double)(2*(i+24)+19)/72.0);
-      win[1][i+30]=win[3][i]=0.0;
-      win[3][i+6 ]=0.5*sin(PI_24*(double)(2*i+1))/cos(MY_PI*(double)(2*(i+6)+19)/72.0);
+    win[0][i]=win[1][i]=0.5*sin(PI_72*(double)(2*(i+0)+1))/cos(MY_PI * (double) (2*(i+0) +19) / 72.0 );
+    win[0][i+18] = win[3][i+18] = 0.5 * sin( MY_PI / 72.0 * (double) (2*(i+18)+1) ) / cos ( MY_PI * (double) (2*(i+18)+19) / 72.0 );
+  }
+  /*
+    for(;i<36;i++) {
+    win[0][i]=win[3][i]=0.5*sin(PI_72*(double)(2*i+1))/cos(PI_72*(double)(2*i+19));
+    
     }
-    for(i=0;i<12;i++)
-      win[2][i]=0.5*sin(PI_24*(double)(2*i+1))/cos(MY_PI*(double)(2*i+7)/24.0);
+  */
+  for(i=0;i<6;i++) {
+    win[1][i+18]=0.5/cos(MY_PI*(double)(2*(i+18)+19)/72.0);
+    win[3][i+12]=0.5/cos(MY_PI*(double)(2*(i+12)+19)/72.0);
+    win[1][i+24]=0.5*sin(PI_24*(double)(2*i+13))/cos(MY_PI*(double)(2*(i+24)+19)/72.0);
+    win[1][i+30]=win[3][i]=0.0;
+    win[3][i+6 ]=0.5*sin(PI_24*(double)(2*i+1))/cos(MY_PI*(double)(2*(i+6)+19)/72.0);
   }
-
-  for(int i=0;i<9;i++)
+  for(i=0;i<12;i++)
+    win[2][i]=0.5*sin(PI_24*(double)(2*i+1))/cos(MY_PI*(double)(2*i+7)/24.0);
+  
+  
+  for(i=0;i<9;i++)
     cos_18[i]=cos(PI_18*double(i));
-  for(int i=0;i<9;i++)
+  for(i=0;i<9;i++)
     hsec_36[i]=0.5/cos(PI_36*double(i*2+1));
-  for(int i=0;i<3;i++)
+  for(i=0;i<3;i++)
     hsec_12[i]=0.5/cos(PI_12*double(i*2+1));
-
-  for(int i=0;i<40;i++)
+  
+  for(i=0;i<40;i++) {
     two_to_negative_half_pow[i]=(REAL)pow(2.0,-0.5*(double)i);
-  {
-    REAL *TO_FOUR_THIRDS=TO_FOUR_THIRDSTABLE+FOURTHIRDSTABLENUMBER;
-
-    for(int i=0;i<FOURTHIRDSTABLENUMBER;i++)
-      TO_FOUR_THIRDS[-i]=
-	-(TO_FOUR_THIRDS[i]=(REAL)pow((double)i,4.0/3.0));
   }
 
-  for(int i=0;i<256;i++) {
+  REAL *TO_FOUR_THIRDS=TO_FOUR_THIRDSTABLE+FOURTHIRDSTABLENUMBER;
+  
+  for(i=0;i<FOURTHIRDSTABLENUMBER;i++)
+    TO_FOUR_THIRDS[-i]=
+      -(TO_FOUR_THIRDS[i]=(REAL)pow((double)i,4.0/3.0));
+
+
+  for(i=0;i<256;i++) {
     POW2[i]=(REAL)pow(2.0,(0.25*(i-210.0)));
   }
-
-  for(int i=0,j,k;i<8;i++)
+  
+  for(i=0;i<8;i++)
     for(j=0;j<2;j++)
       for(k=0;k<16;k++)POW2_1[i][j][k]=pow(2.0,(-2.0*i)-(0.5*(1.0+j)*k));
-
-  {
-    static REAL TAN12[16]=
-    { 0.0,        0.26794919, 0.57735027  , 1.0,
-      1.73205081, 3.73205081, 9.9999999e10,-3.73205081,
-      -1.73205081,-1.01,      -0.57735027,  -0.26794919,
-      0.0,        0.26794919, 0.57735027,   1.0};
-
-    for(int i=0;i<16;i++)
-    {
-      rat_1[i].l=TAN12[i]/(1.0+TAN12[i]);
-      rat_1[i].r=1.0/(1.0+TAN12[i]);
-    }
+  
+  static REAL TAN12[16]=
+  { 0.0,        0.26794919, 0.57735027  , 1.0,
+    1.73205081, 3.73205081, 9.9999999e10,-3.73205081,
+    -1.73205081,-1.01,      -0.57735027,  -0.26794919,
+    0.0,        0.26794919, 0.57735027,   1.0};
+  
+  for(int i=0;i<16;i++) {
+    rat_1[i].l=TAN12[i]/(1.0+TAN12[i]);
+    rat_1[i].r=1.0/(1.0+TAN12[i]);
   }
+  
 
 #define IO0 ((double)0.840896415256)
 #define IO1 ((double)0.707106781188)
   rat_2[0][0].l=rat_2[0][0].r=
   rat_2[1][0].l=rat_2[1][0].r=1.;
 
-  for(int i=1;i<64;i++)
-    if((i%2)==1)
-    {
+  for(i=1;i<64;i++) {
+    if((i%2)==1) {
       rat_2[0][i].l=pow(IO0,(i+1)/2);
       rat_2[1][i].l=pow(IO1,(i+1)/2);
       rat_2[0][i].r=
       rat_2[1][i].r=1.;
     }
-    else
-    {
+    else {
       rat_2[0][i].l=
       rat_2[1][i].l=1.;
       rat_2[0][i].r=pow(IO0,i/2);
       rat_2[1][i].r=pow(IO1,i/2);
     }
+  }
 
-  {
-    static REAL Ci[8]=
-    {-0.6f,-0.535f,-0.33f,-0.185f,-0.095f,-0.041f,-0.0142f,-0.0037f};
-    REAL sq;
-
-    for(int i=0;i<8;i++)
-    {
-      sq=sqrt(1.0f+Ci[i]*Ci[i]);
-      cs[i]=1.0f/sq;
-      ca[i]=Ci[i]*cs[i];
-    }
+  static REAL Ci[8]=
+  {-0.6f,-0.535f,-0.33f,-0.185f,-0.095f,-0.041f,-0.0142f,-0.0037f};
+  REAL sq;
+  
+  for(i=0;i<8;i++) {
+    sq=sqrt(1.0f+Ci[i]*Ci[i]);
+    cs[i]=1.0f/sq;
+    ca[i]=Ci[i]*cs[i];
   }
 
   initializedlayer3=true;
@@ -784,7 +771,13 @@ void Mpegtoraw::layer3huffmandecode(int ch,int gr,int out[SBLIMIT][SSLIMIT])
     if(h->treelen) {
       while(i<end)
 	{
-	  huffmandecoder_1(h,&out[0][i],&out[0][i+1]);
+	  int skip = HuffmanLookup::decode(h->tablename, bitwindow.peek8(),
+	  				&out[0][i], &out[0][i+1]);
+
+      if(skip)
+	    bitwindow.forward(skip);
+	  else 
+	    huffmandecoder_1(h,&out[0][i],&out[0][i+1]);
 	  i+=2;
 	}
     } else {
@@ -1137,8 +1130,8 @@ inline void Mpegtoraw::layer3fixtostereo(int gr,REAL in[2][SBLIMIT][SSLIMIT])
 	for(int j=0;j<3;j++)
 	{
 	  int sfbcnt=-1;
-
-	  for(int sfb=12;sfb>=0;sfb--)
+	  int sfb;
+	  for(sfb=12;sfb>=0;sfb--)
 	  {
 	    int lines;
 
@@ -1158,7 +1151,7 @@ inline void Mpegtoraw::layer3fixtostereo(int gr,REAL in[2][SBLIMIT][SSLIMIT])
 	      }
 	  }
 
-	  for(int sfb=sfbcnt+1;sfb<12;sfb++)
+	  for(sfb=sfbcnt+1;sfb<12;sfb++)
 	  {
 	    int k,t;
 
