@@ -23,9 +23,9 @@
 
 class TplayPlugin : public DecoderPlugin {
 
-  struct info_struct* info;
-  struct TimeStamp* startStamp;
-  struct TimeStamp* endStamp;
+  class info_struct* info;
+  class TimeStamp* startStamp;
+  class TimeStamp* endStamp;
 
  public:
   TplayPlugin();
