@@ -18,6 +18,17 @@
 #include "audioIO.h"
 #include <iostream.h>
 
+/**
+   This class wraps the platform specific /dev/dsp implementation.
+   The only unusal thing is, that it supports each order of
+   init/open.
+   i) you can first init the device and the open
+   ii) you can first open the device and the init it
+   The implementation takes care that the calls are forwarded
+   in the right order to the /dev/dsp implementation.
+   (means: before the init it, we need to open it)
+   But a caller can do it in both orders.
+*/
 
 class AudioWrapper {
 
@@ -26,6 +37,8 @@ class AudioWrapper {
   int samplesize;
   int speed;
   int stereo;
+  int lNeedInit;
+  int lHasInitData;
 
  public:
   AudioWrapper();
