@@ -15,10 +15,18 @@
 
 
 ImageBase::ImageBase() {
+	identifier = NULL;
 }
 
 
 ImageBase::~ImageBase() {
+	if (identifier != NULL)
+		delete [] identifier;
+}
+
+void ImageBase::init(XWindow* xWindow, YUVPicture*)
+{
+  cout << "direct virtual call: ImageBase::init  "<<endl;
 }
 
 int ImageBase::support() {
@@ -26,7 +34,7 @@ int ImageBase::support() {
   return false;
 }
 
-int ImageBase::openImage(int) {
+int ImageBase::openImage(int)  {
   cout << "direct virtual call: ImageBase::openImage  "<<endl;
   return false;
 }
@@ -45,3 +53,17 @@ void ImageBase::ditherImage(YUVPicture*) {
 void ImageBase::putImage() {
   cout << "direct virtual call: ImageBase::putImage  "<<endl;
 }
+
+void ImageBase::setIdentifier(const char *id)
+{
+	if (identifier != NULL)
+		delete [] identifier;
+
+	identifier = new char [strlen(id) + 1];
+	strcpy(identifier, id);
+}
+
+char *ImageBase::getIdentifier()
+{
+	return identifier;
+}
