@@ -24,9 +24,14 @@
 #endif  
 
 #ifdef SDL_WRAPPER
+
+#if defined WIN32
+#include <SDL.h>
+#include <SDL_video.h>
+#else
 #include <SDL/SDL.h>
 #include <SDL/SDL_video.h>
-
+#endif
 
 class ImageDeskSDL : public ImageBase {
 
@@ -35,15 +40,17 @@ class ImageDeskSDL : public ImageBase {
 
   SDL_Surface* surface;
   SDL_Rect* rect;
-
+  int imageMode;
 
  public:
-  ImageDeskSDL(SDL_Surface* surface,SDL_Rect* rect);
+  ImageDeskSDL();
   ~ImageDeskSDL();
 
   int support();
+  void init(XWindow* xWindow, YUVPicture* pic=NULL);
 
-  int openImage(int ditherSize);
+
+  int openImage(int imageMode);
   int closeImage();
 
   void ditherImage(YUVPicture* pic);
