@@ -27,18 +27,20 @@
 #endif  
 
 #ifdef SDL_WRAPPER
-
+#if defined WIN32
+#include <SDL.h>
+#include <SDL_video.h>
+#else
 #include <SDL/SDL.h>
 #include <SDL/SDL_video.h>
-
+#endif
 
 
 class SDLSurface : public Surface {
 
   int lOpen;
-  int imageSize;
   int imageMode;
-  
+  int lSDLInit;
   int video_bpp;
   SDL_Surface* surface;
   SDL_Rect rect;
@@ -53,15 +55,22 @@ class SDLSurface : public Surface {
   ~SDLSurface();
 
   int isOpen();
-  int open(int width, int height,const char *title);
+  int open(int width, int height,const char *title, bool border=false);
   int close();
   int getHeight();
   int getWidth();
   int getDepth();
+  int getImageMode();
+  int checkEvent(int* mode);
 
-  int openImage(int imageSize,int imageMode);
+  int openImage(int imageMode, YUVPicture* pic = NULL);
   int closeImage();
   int dither(YUVPicture* pic);
+  int putImage(YUVPicture* pic);
+
+
+ private:
+  void sdlinit();
 };
 #endif
 
