@@ -17,21 +17,18 @@
 #include "xinit.h"
 
 #include "../imageBase.h"
-
+#include "../dither2YUV/dither2YUV.h"
 
 #include <iostream.h>
 #include <stdio.h>
-#include <unistd.h>
-#include <limits.h>
-#include <sys/types.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <unistd.h>
-#include <time.h>
+#include <semaphore.h>
 
 //#undef X11_XV
 
 #define GUID_YUV12_PLANAR 0x32315659
+#define GUID_I420_PLANAR  0x30323449
+#define GUID_YUY2_PACKED  0x32595559
+#define GUID_UYVY_PACKED  0x59565955
 
 /**
    The XV extension dither yuv images in hardware and allows 
@@ -44,37 +41,45 @@
 class ImageXVDesk : public ImageBase {
 
 #ifdef X11_XV
-  XvAdaptorInfo		*ai;
-  XvEncodingInfo	*ei;
-  XvAttribute		*at;
-  XvImageFormatValues	*fo;
+  XvAdaptorInfo		  *ai;
+  XvEncodingInfo	  *ei;
+  XvAttribute		  *at;
+  XvImageFormatValues *fo;
 
-  XvImage		*yuv_image;
+  XvImage		 *yuv_image;
+  bool            keepRatio;
 
-
-  int		        xv_port;
-
-  int 			shmem_flag;
-  XShmSegmentInfo	yuv_shminfo;
+  int		      xv_port;
+  int             imageID;
+  
+  int 			  shmem_flag;
+  XShmSegmentInfo yuv_shminfo;
 #endif
+  Dither2YUV*    ditherWrapper;
 
   int lSupport;
   XWindow* xWindow;
 
  public:
-  ImageXVDesk(XWindow* xWindow);
+  ImageXVDesk();
   ~ImageXVDesk();
 
+  void init(XWindow* xWindow, YUVPicture* pic = NULL);
+
   int support();
 
-  int openImage(int ditherSize);
+  int openImage(int imageMode);
   int closeImage();
 
   void ditherImage(YUVPicture* pic);
   void putImage();
 
+  void setKeepRatio(bool enable);
+  
  private:
   int haveXVSupport(XWindow* xWindow);
+  void freeImage();
+  void createImage(int id);
 
 };
 
