@@ -16,7 +16,7 @@
 
 
 #include "decoderBaseObject_impl.h"
-#include "../mpeglib/lib/decoder/decoderPlugin.h"
+#include "../mpeglib/lib/decoder/vorbisPlugin.h"
 
 
 // for dynamic loading
